/////////////////////////////////////////////////////////////////////
// Delphi Interfaces for OASIS controller family
// Copyright 2000-2010 Objective Imaging, Ltd.
/////////////////////////////////////////////////////////////////////

unit oasis4i;

interface

uses
  Windows, SysUtils;

///////////////// OI DLL CONSTANTS /////////////////

const OI_OK			    = 0;
const OI_FAILED		  = 1;
const OI_ABORT		  = 2;
const OI_NOHARDWARE	= 4;
const OI_TIMEOUT		= 8;
const OI_INVALIDARG	= 16;
const OI_HARDWAREBUSY = 32;
const OI_ACCESSDENIED	=	64;
const OI_NOTSUPPORTED	=	128;
const OI_ILLEGALAXIS	=	256;
const OI_INVALIDCONFIG =	512;
const OI_MAXMOVEFAIL	 =	1024;

const OI_STATUS_STOPPED = 0;
const OI_STATUS_MOVING = 1;

const OI_XAXIS: Integer = 1;
const OI_YAXIS: Integer = 2;
const OI_ZAXIS: Integer = 3;
const OI_FAXIS: Integer = 4;
const OI_TAXIS: Integer = 5;
const OI_SAXIS: Integer = 6;

///////////////////////////////////////////
// AXIS ID HANDLING
///////////////////////////////////////////
const OI_MULTI_MODE_ID: Integer = 0; // use 1-4*N, N=number of boards
const OI_MULTI_MODE_ROUTE: Integer = 1; // use 1-4 on each board

const S_PCB_MOTOR_VOLTS_OK: Integer =		  $1;
const S_PCB_TEMP_OK: Integer =				    $2;
const S_PCB_ADC_YIN_OK: Integer =			    $4;
const S_PCB_ADC_XIN_OK: Integer =			    $8;
const S_PCB_AF_FITTED: Integer =				  $10;
const S_PCB_AF_TYPE0: Integer =				    $20;
const S_PCB_AF_TYPE1: Integer =				    $40;
const S_PCB_VIDEO_ENCODER_OK: Integer =		$80;
const S_PCB_CAMERA_DETECTED: Integer =		$100;
const S_PCB_CAMERA_CHANNEL: Integer =		  $200;
const S_PCB_CAMERA_FREQ: Integer =			  $400;
const S_PCB_CAMERA_TYPE: Integer =			  $800;
const S_PCB_SERIAL_DEV_DETECTED: Integer =	$1000;
const S_PCB_MOUSE_DETECTED: Integer =		  $2000;
const S_PCB_TRACKBALL_FITTED: Integer =		$4000;
const S_PCB_JOYSTICK_FITTED: Integer =		$10000;
const S_PCB_FLASH_OI_OK: Integer =			  $40000;
const S_PCB_FLASH_USER_OK: Integer =			$80000;

const S_PCBEX_XA1_FITTED: Integer =         $4;
const S_PCBEX_DC1_FITTED: Integer =         $1;
const S_PCBEX_EXPIO_FITTED: Integer = 		$3;

///////////////////////////////////////////
// OASIS-4i Modules
///////////////////////////////////////////
const OASIS_AF: Integer =		1;
const OASIS_XA1: Integer =	2;
const OASIS_DC1: Integer	=	3;

///////////////////////////////////////////
// OASIS-blue Modules
///////////////////////////////////////////
const BLUE_EXPIO: Integer =		4;
const BLUE_DAC: Integer =		5;

const S_LIMIT_PHY_NEG: WORD	=  $0001;
const S_LIMIT_USR_NEG: WORD	=  $0002;
const S_LIMIT_PHY_POS: WORD	=  $0008;
const S_LIMIT_USR_POS: WORD	=	 $0004;
const S_LIMIT_USR_NEG_SET: WORD = $0010;
const S_LIMIT_USR_POS_SET: WORD = $0020;
const S_INITIALIZED: WORD	=	    $0040;
const S_DIRECTION: WORD =		    $0080;
const S_MOVING: WORD =		      $0100;
const S_MOTOR_DETECTED: WORD =  $8000;

const OI_NOTFITTED		= -1;
const OI_SIM		= 0;
const OI_OASIS	= 1;
const OI_REMOTE  = 2;
const OI_GLIDE    = 4;
const OI_LEICA_DM	 =	10;
const OI_LEICA_DM2  = 11;
const OI_LEICA_MZ   = 12;
const OI_OLYMPUS_BX =   20;
const OI_NAVITAR = 50;
const OI_OPTEM = 51;
const OI_NANOZ = 60;
const OI_OASIS_DAC	=	100;
const	OI_BLUE_DAC1	=	OI_OASIS_DAC+1;
const	OI_BLUE_DAC2	=	OI_OASIS_DAC+2;
const	OI_BLUE_DAC3	=	OI_OASIS_DAC+3;
const	OI_BLUE_DAC4	=	OI_OASIS_DAC+4;
const OI_PRIOR_LUMEN		= 81;
const OI_CRI_MICROCOLOR	= 90;

const OI_CFG_STAGE	 =	1;

const	OI_CFG_FOCUS	 =	2;
const	OI_CFG_FINEFOCUS = 3;
const OI_CFG_AUTOFOCUS =	4;
const	OI_CFG_SMARTFOCUS = 5;

const	OI_CFG_FILTER	 =	8;
const OI_CFG_FILTER2	 =	16;
const	OI_CFG_TURRET	 =	32;
const OI_CFG_LAMP1	 =	64;
const OI_CFG_LAMP2	 =	128;

const OI_CFG_SHUTTER1 = 256;

const OI_CFG_CHANGER =	$1000;


const OI_CAP_DEVICE_UNLICENSED	= $10000000;

///////////////////////////////////////////
// DEVICE IDs
///////////////////////////////////////////
const		OASIS_4I =	0;
const		OASIS_BLUE = 1;
const		OASIS_EXPRESS	= 2;
const		OASIS_USB		= 3;
const   OASIS_GLIDE = 4;

////////////////////////////////////////////////////////
// OI-SC4 Shutter Controller masks
////////////////////////////////////////////////////////
const SHUTTER1	= 1;
const SHUTTER2	= 2;
const SHUTTER3	= 4;
const SHUTTER4	= 8;
const  OI_SHUTTER_OPEN =  65535;
const  OI_SHUTTER_CLOSE	= 0;

const  OI_FILTER_OTHER	=	0;
const  OI_FILTER_LUDL		= 1;
const  OI_FILTER_PRIOR	=	2;
const  OI_FILTER_SUTTER	= 3;

////////////////////////////////////////////////////////
// Filter initialization methods
////////////////////////////////////////////////////////
const  OI_FILTER_INIT_HOME		 = 0;
const  OI_FILTER_INIT_LIMITS	 = 1;
const  OI_FILTER_INIT_USER		 = 2;

////////////////////////////////////////////////////////
// Predictive focus
////////////////////////////////////////////////////////
const  OI_PF_MULTI_PLANE	 = 0;
const  OI_PF_SINGLE_PLANE	 = 1;
const  OI_PF_LOCAL_MEAN		 = 2;
const  OI_PF_TRIANGULATE   = 3;

type
SHUTTERINFO = record
	wDurationHV: WORD ; // High Voltage duration (20-100 mS)
	wTimerHV: WORD; // High Voltage current timer value (20-100 mS)
	wDurationLV: WORD; // Low (holding) Voltage duration (0 to 65535 mS)
	wTimerLV: WORD; // Low (holding) Voltage current timer value (0 to 65535 mS)
end;

////////////////////////////////////////////////////////
// Logging Levels
////////////////////////////////////////////////////////

const OI_LOG_CMD				      = $1;
const OI_LOG_DRIVER_CMD	      = $2;
const OI_LOG_BASIC_READS		  = $4;
const OI_LOG_POS_READS		    = $8;
const OI_LOG_STATUS_READS		  = $10;
const OI_LOG_POS_READS_DRV	  = $20;
const OI_LOG_STATUS_READS_DRV	  = $40;
const	OI_LOG_DRIVER			      = $80;
const OI_LOG_PRED_Z			      = $100;
const OI_LOG_PRED_Z_UPDATES	  = $200;

const OI_LOG_ALL				      = $ffff;

////////////////////////////////////////////////////////
// License IDs
////////////////////////////////////////////////////////
const  OI_LIC_ACTIVEX			= 0;
const  OI_LIC_SYNCRO			= 1;
const  OI_LIC_SURVEYOR		=	2;
const  OI_LIC_TURBOSCAN		= 3;
const  OI_LIC_OLYMPUS			= 4;
const  OI_LIC_DISCEXP			= 5;
const  OI_LIC_NAVIGATOR		= 6;
const  OI_LIC_ZSTACK			= 7;
const  OI_LIC_MARKFIND		=	8;
const  OI_LIC_SURVEYORLITE = 9;
const  OI_LIC_SLIDEX			= 10;
const  OI_LIC_MULTICHAN		= 11;
const  OI_LIC_DETECTOR		=	12;
const  OI_LIC_SLIDELOADER	=	13;
const  OI_LIC_WAFERSHUTTLE	=	14;


///////////////////////////////////////////////////////////////////////////////
// FUNCTION DECLARATIONS
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// Hardware defs
///////////////////////////////////////////////////////////////////////////////
function 	OI_SetHardwareMode(nMode: Integer): Integer; stdcall; external 'oasis4i.dll';
function 	OI_GetHardwareMode(var nMode: Integer): Integer; stdcall; external 'oasis4i.dll';

function	OI_GetHardwareModeCount( var pnCount: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetHardwareModeInfo( nZeroBasedIndex: Integer; var pnMode: Integer; var pnType: Integer; szName: PChar; nStringLen: Integer ): Integer; stdcall; external 'oasis4i.dll';

function  OI_Open(): Integer; stdcall; external 'oasis4i.dll';
function  OI_OpenEx(iReserved: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_Close(): Integer; stdcall; external 'oasis4i.dll';
function 	OI_GetDriverOpen(var bOpen: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadPCBTemperature(var dTempC: Double): Integer; stdcall; external 'oasis4i.dll';
function  OI_EmergencyStopAll(): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadPCBStatus(var lpdwHWState: DWORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadPCBStatusEx(var lpwExStatusWords: WORD): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadPCBType( var pnType: Integer ): Integer; stdcall; external 'oasis4i.dll';
function 	OI_IsModuleFitted(nModule:Integer; var bFitted: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetCardType( nCard: Integer; var pnType: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetCardAxisCount( nCard: Integer; var pnAxisCount: Integer ): Integer; stdcall; external 'oasis4i.dll';

function	OI_EnableMotorPowerEx(var pwMotors: WORD): Integer; stdcall; external 'oasis4i.dll';

function  OI_ReadADCValues( var pwValArray: WORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAutoFocusHWMode(nMode: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAutoFocusHWMode(var pnMode: Integer): Integer; stdcall; external 'oasis4i.dll';

function  OI_Configure( nComponent, nControl: Integer ): Integer; stdcall; external 'oasis4i.dll';
function  OI_OpenComponent( nComponent: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetConfiguration( nComponent: Integer; var pnControl: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_CloseComponent( nComponent: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_InitComponent( nComponent: Integer ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetAutoOpenExtDevice( bAutoOpen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAutoOpenExtDevice( var lpbAutoOpen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAutoConnectOptions( dwOptions: DWORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAutoConnectOptions(var lpdwOptions: DWORD): Integer; stdcall; external 'oasis4i.dll';


function	OI_GetAvailControllerCount( nComponent: Integer; var pnCount: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetControllerName( nComponent, nIndex: Integer; szName: PChar; nStringLen: Integer; var pnID: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetControllerID( inComponent, nIndex: Integer; var pnID: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetControllerCapabilities( nComponent, nID: Integer; var nCaps: Integer): Integer; stdcall; external 'oasis4i.dll';

function  OI_SetDefaultWaitCursorEnabled( bEnabled: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetDefaultWaitCursorEnabled( var pbEnabled: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetUseCount( var pnUsers: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ResetHardware(): Integer; stdcall; external 'oasis4i.dll';


function	OI_SetEncoderModule( wOutputPulseWidth_usec: WORD ;
							wComparitor1On: WORD; dwComparitor1Value: DWORD;
							wComparitor2On:WORD; dwComparitor2Value: DWORD;
							wReserved: WORD; dwReserved: DWORD;
							wReserved2: WORD; dwReserved2: DWORD;
							wOptions:WORD ): Integer; stdcall; external 'oasis4i.dll';

function	OI_ReadEncoderModule( var pwInfo: WORD; var pwOptions: WORD; var pwOutputPulseWidth_usec: WORD;
							var pdwComparitor1: DWORD;
							var pdwComparitor2: DWORD;
							var pdwReserved: DWORD;
							var pdwReserved2: DWORD): Integer; stdcall; external 'oasis4i.dll';

function	OI_ReadEncoderValues( var pdX: double; var pdY: double; var pdZ: double; var pdF: double ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////
// Multiple card support
function	OI_CountCards( var pnFound: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SelectCard( nCard: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetSelectedCard( var pnCard: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadCardStatus(  nCard: Integer; var lpdwStatus: DWORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetMultiAxisMode( nMode: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetMultiAxisMode( var pnMode: Integer ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////
// Version functions
function  OI_GetDriverVersion(sVersion: PChar; nStringLen: integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadPCBID( sIDBuffer: PChar; nStringLen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadPCBVersion( sVersion: PChar; nStringLen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadSerialNum(nCard: Integer; szSerialNum: PChar; nStringLen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadPCBName(nCard: Integer; szName: PChar; nStringLen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetLicenseInfo( LicenseID: Integer; var pbyInfo: Byte ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////////////
// Axes configurations
///////////////////////////////////////////////////////////////////////////////
function  OI_GetXYFitted(var bFitted: Boolean): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetXYFitted(bFitted: Boolean): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetZFitted(var bFitted: Boolean): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetZFitted(bFitted: Boolean): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetFAxisFitted(var bFitted: Boolean): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetFAxisFitted(bFitted: Boolean): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetAFFitted(var bFitted: Boolean): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetAFFitted(bFitted: Boolean): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////////////
// Full axes
///////////////////////////////////////////////////////////////////////////////
function	OI_MoveToXYZ(X, Y, Z: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_MoveToXYZ_Auto(X, Y, Z: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadXYZ(var X, Y, Z: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_WaitForStoppedXYZ(nXStop, nYStop, nZStop: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_DriveContinuousXYZ( nXSpeed, nYSpeed, nZSpeed: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadMaxMoveXYZ(var lpdwXSteps: DWORD; var lpwXDecel: WORD;
                            var lpdwYSteps: DWORD; var lpwYDecel: WORD;
                            var lpdwZSteps: DWORD; var lpwZDecel: WORD ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////////////
// Single axis
///////////////////////////////////////////////////////////////////////////////
function	OI_GetAxisEnabled( AxisID: Integer; var pbEnabled: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function  OI_MoveAxis   (AxisID: Integer; Pos: Double; Wait: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadAxis   (AxisID: Integer; var Pos: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisRange(AxisID: Integer; var Min, Max: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAxisStepSize(AxisID: Integer; StepSize: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisStepSize(AxisID: Integer; var StepSize: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAxisBacklash(AxisID: Integer; Enabled: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisBacklash(AxisID: Integer; var Enabled: BOOL): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetAxisType(AxisID: Integer; nType: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetAxisType(AxisID: Integer; var nType: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetAxisCruise(AxisID: Integer; Cruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetAxisCruise(AxisID: Integer; var Cruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetAxisSense(AxisID: Integer; var pnSense: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetAxisSense(AxisID: Integer; nSense: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetAxisRamp(AxisID: Integer; var pnRamp: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetAxisRamp(AxisID: Integer; nRamp: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_DriveAxisContinuous(AxisID: Integer; Speed: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepAxis(AxisID: Integer; dValue: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAxisInitMethod(AxisID: Integer; nMethod: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisInitMethod(AxisID: Integer; var nMethod: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadAxisAtLimit(AxisID: Integer; var pbAtNegLimit: BOOL; var pbAtPosLimit: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadAxisMoving(AxisID: Integer; var pbIsMoving: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadAxisStatus(AxisID: Integer; var lpwStatus: WORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAxisToDefaults(AxisID: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadAxisRampValue(AxisID: Integer; wIndex: WORD; var lpwInterval: WORD; var lpwStepSize: WORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_HaltAxis(AxisID: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisStepsPerRev( AxisID: Integer; var lpdwStepsPerRev: DWORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAxisTravel(AxisID: Integer; dMin, dMax: double): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisTravel(AxisID: Integer; var pdMin: double; var pdMax: double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAxisPosition(AxisID: Integer; dNewPos: double): Integer; stdcall; external 'oasis4i.dll';
function	OI_ClearAxisUserLimits( AxisID: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_InitAxisByLimits( AxisID: Integer; var pdMin: double; var pdMax: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAxisPitch( AxisID: Integer; dPitchMM: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisPitch( AxisID: Integer; var pdPitchMM: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_LookupAxisSpeed( AxisID, nCruise: Integer; var pdSpeed: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAxisUserLimits( AxisID: Integer; dMin, dMax: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisUserLimits( AxisID: Integer; var dMin: double; var dMax: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_InitAxisToHome( AxisID: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisHomeInfo( AxisID: Integer; var pUnitsPerRev: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ClearAxisHome( AxisID: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadAxisHome( AxisID: Integer; var lpbHomeFound: BOOL; var pdHomeLeft: double; var pdHomeRight: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisMaxMove( AxisID: Integer; var lpdwValue: DWORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepAxisAbs( AxisID: Integer; lSteps: Integer; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////
// Encoder support
function	OI_GetAxisEncoderFitted( AxisID: Integer; var lpbEnabled: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisEncoderEnabled( AxisID: Integer; var lpbEnabled: BOOL; var lpbAutoCorrect: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAxisEncoderEnabled( AxisID: Integer; bEnabled, bAutoCorrect: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisEncoderStepSize( AxisID: Integer; var pdMicrons: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetEncoderEnabledXY(  bEnabledX: BOOL; nTolX: Integer; bEnabledY: BOOL; nTolY: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetEncoderEnabledXY( var pbEnabledX: BOOL; var pnTolX: Integer; var pbEnabledY: BOOL; var pnTolY: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetEncoderEnabledZ( bEnabled: BOOL; nTol: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetEncoderEnabledZ( var pbEnabled: BOOL; var pnTol: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetEncoderEnabledF( bEnabled: BOOL; nTol: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetEncoderEnabledF( var pbEnabled: BOOL; var pnTol: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisEncoderFactor(  AxisID: Integer; var  piuStepsPerEncoder: Integer ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetEncoderClosedLoopResponseXYZ( nResponseX, nResponseY, nResponseZ: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetEncoderClosedLoopResponseXYZ( var pnResponseX: Integer; var pnResponseY: Integer; var pnResponseZ: Integer ): Integer; stdcall; external 'oasis4i.dll';


///////////////////////////////////////////////////////////////////////////////
// X and Y Axes
///////////////////////////////////////////////////////////////////////////////
function  OI_InitializeXY(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetOriginXY(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPositionXY( XPos, YPos: Double): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadXY(var X, Y: Double): Integer; stdcall; external 'oasis4i.dll';
function  OI_MoveToXY(X, Y: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_MoveToXY_Auto(X, Y: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepX(XDistance: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_StepY(YDistance: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepXY(XDistance, YDistance: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadStatusXY(var XStatus, YStatus: WORD): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetPitchXY(var XPitch, YPitch: Double): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetPitchXY(XPitch, YPitch: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetRampXY(XRamp, YRamp: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetRampXY(var XRamp, YRamp: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetCruiseXY(XCruise, YCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetCruiseXY(var XCruise, YCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetDriveSenseXY(XDir, YDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetDriveSenseXY(var XDir, YDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_DriveContinuousXY(XSpeed, YSpeed: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_HaltXY(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetUserLimitsXY(XMin, XMax, YMin, YMax: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetUserLimitsXY(var XMin, XMax, YMin, YMax: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadLimitAlarmsXY(var XNeg, XPos, YNeg, YPos: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ClearUserLimitsXY(): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetSpeedXY( var pdXSpeed, pdYSpeed: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SelectSpeedXY( dXmmPerSec, dYmmPerSec: Double; nFlags: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_LookupSpeedXY( nXCruise, nYCruise: Integer; var pdXSpeed, pdYSpeed: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFullTravelXY( var pdXMin, pdXMax, pdYMin, pdYMax: Double; var fInit: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetUserLimitGuardDistanceXY( dXDistanceMicrons, dYDistanceMicrons: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetUserLimitGuardDistanceXY( var pdXDistanceMicrons, pdYDistanceMicrons: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_WaitForStoppedXY(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetUserLimitsEnabledXY( bXMinEnabled, bXMaxEnabled, bYMinEnabled, bYMaxEnabled: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetUserLimitsEnabledXY( var pbXMinEnabled: BOOL; var pbXMaxEnabled: BOOL; var pbYMinEnabled: BOOL; var pbYMaxEnabled: BOOL ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetAxisSwapXY( bSwapped: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAxisSwapXY( var pbSwapped: Integer ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////////////
// Z Axis
///////////////////////////////////////////////////////////////////////////////
function  OI_InitializeZ( dRangeAbove, dRangeBelow: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPositionZ(dZPos: Double): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadZ(var Z: Double): Integer; stdcall; external 'oasis4i.dll';
function  OI_MoveToZ(Z: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepZ(ZDistance: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadStatusZ(var nStatus: WORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetRampZ(nZRamp: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetRampZ(var ZRamp: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetCruiseZ(ZCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetCruiseZ(var ZCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetDriveSenseZ(ZDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetDriveSenseZ(var ZDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_DriveContinuousZ(nSpeed: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_HaltZ(): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadRangeZ( var dZMin: Double; var dZMax: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetUserLimitsZ(dZMin, dZMax: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetUserLimitsZ(var pdZMin: Double; var pdZMax: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetFocusJoystick(nLeft, nRight: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetOriginZ(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetMouseWheelZ(bEnabled: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetMouseWheelZ(var pbEnabled: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetMouseWheelSteps(dFine, dCoarse: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetMouseWheelSteps(var pdFine: Double; var pdCoarse: Double): Integer; stdcall; external 'oasis4i.dll';
function  OI_OpenMouseWheelForFocus(hinstModule: LongWord; dwThreadId: DWORD): Integer; stdcall; external 'oasis4i.dll';
function  OI_CloseMouseWheelForFocus(): Integer; stdcall; external 'oasis4i.dll';
function	OI_ClearUserLimitsZ(): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetSpeedZ( var pdSpeed: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SelectSpeedZ( dZmmPerSec: Double; nFlags: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_LookupSpeedZ( nCruise: Integer; var pdSpeed: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPitchZ(dZPitch: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPitchZ(var pdZPitch: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPortZ(szBuffer: PChar): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPortZ(szBuffer: PChar; nBufferLen: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadSyncZ(var pwFieldNum: WORD; var pZ: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadSyncPositions(var pwFieldNum: WORD;  var pX: Double;  var pY: Double; var pZ: Double): Integer; stdcall; external 'oasis4i.dll';


////////////////////////////////////////////////////////
// predictive focus
function	OI_SetPredictiveZ( var xvals, yvals, zvals: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPredictiveZ( x, y: Double; var zpred: Double; var status : Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPredictiveFlag( var pbFlag: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPredictiveFlag( bFlag: BOOL ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetAutoPredictiveZ( bEnabled: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAutoPredictiveZ( var pbEnabled, pbValid: BOOL; var pdZPred: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAutoPredictiveZParams(dX1, dY1, dZ1,
                dC1, dC2, dC3: Double ): Integer; stdcall; external 'oasis4i.dll';

function	OI_GetAutoPredictiveZParams( var pbEnabled, pbValid: BOOL;
				var pdX1, pdY1, pdZ1: Double;
				var pdC1, pdC2, pdC3: Double
				): Integer; stdcall; external 'oasis4i.dll';
function	OI_InvalidatePredictiveZ(): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetMultiPredictiveZ(
        nMethod: Integer;
        nPoints: Integer;
        var xvals: double; var yvals: double; var zvals: double
        ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetMultiPredictiveZ( var pnMethod: Integer; var pnPoints: Integer; var xvals: double; var yvals: double; var zvals: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_UpdatePredictiveZ(nOption: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPredictiveZDomains(
        var pnDomains: Integer;
        var ax: double;
        var ay: double;
        var az: double;
        var bx: double;
        var by: double;
        var bz: double;
        var cx: double;
        var cy: double;
        var cz: double
         ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetCoincDomain( xpos, ypos: double; var pnDomainIndex: Integer ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////
// Piezo Z via Dac1 on BLUE-DAC
function	OI_IsPiezoFitted( var pbFitted: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPiezoZ( Z: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadPiezoZ( var pZ: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPiezoOrigin(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPiezoRange( dRangeMicrons: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPiezoRange( var pdRangeMicrons: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPiezoLimits( var pdMin: double; var pdMax: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_InitPiezo( bReadLimits: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPiezoVoltageRange( dMinVolts, dMaxVolts: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPiezoVoltageRange( var pdMinVolts: double; var pdMaxVolts: double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPiezoDirection( iReversed: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPiezoDirection( var iReversed: Integer ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SelectActiveFocusDevice( nCoarseOrFine: integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetActiveFocusDevice( var pnCoarseOrFine: integer ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetFocusReadMode( nFocusReadMode: integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFocusReadMode( var pnFocusReadMode: integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPiezoADCSettings( wADCMin, wADCMax, wADCThresh: WORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPiezoADCSettings(var pwADCMinL: WORD; var pwADCMax: WORD; var pwADCThresh: WORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPiezoDacChannel( nChan: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetPiezoDacChannel( var pnChan: Integer ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////////////
// F Axis
///////////////////////////////////////////////////////////////////////////////
function  OI_InitializeF(): Integer; stdcall; external 'oasis4i.dll';
function  OI_InitializeFRange(FNegLimit, FPosLimit: Double): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetPositionF( FPos: Double): Integer; stdcall; external 'oasis4i.dll'
function  OI_ReadF(var F: Double): Integer; stdcall; external 'oasis4i.dll';
function  OI_MoveToF(F: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepF(FDistance: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadStatusF(var nStatus: WORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetRampF(nFRamp: Integer): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetRampF(var pnFRamp: Integer): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetCruiseF(FCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetCruiseF(var FCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetDriveSenseF(FDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetDriveSenseF(var FDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_DriveContinuousF(nSpeed: Integer): Integer; stdcall; external 'oasis4i.dll'
function	OI_HaltF(): Integer; stdcall; external 'oasis4i.dll'
function	OI_ReadRangeF(var pFMin: Double; var pFMax: Double): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetStepSizeF(var dStepSize: Double): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetStepSizeF(dStepSize: Double): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetOriginF(): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetSpeedF( var pdSpeed: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SelectSpeedF( dFmmPerSec: Double; nFlags: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_LookupSpeedF( nCruise: Integer; var pdSpeed: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ClearUserLimitsF(): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetUserLimitsF(var pFMin: Double; var pFMax: Double): Integer; stdcall; external 'oasis4i.dll'

///////////////////////////////////////////////////////////////////////////////
// T Axis
///////////////////////////////////////////////////////////////////////////////
function  OI_ReadT( var pdPos: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPositionT( dPos: Double): Integer; stdcall; external 'oasis4i.dll'
function  OI_MoveToT(dPos: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepT(dDistance: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadStatusT(var pnStatus: WORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetRampT(nRamp: Integer): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetRampT(var pnRamp: Integer): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetCruiseT(nCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetCruiseT(var pnCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_HaltT(): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetStepSizeT(var pdStepSize: Double): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetStepSizeT(dStepSize: Double): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetOriginT(): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetSpeedT( var pdSpeed: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SelectSpeedT( dFmmPerSec: Double; nFlags: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_LookupSpeedT( nCruise: Integer; var pdSpeed: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ClearUserLimitsT(): Integer; stdcall; external 'oasis4i.dll';
function	OI_DriveContinuousT(nSpeed: Integer): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetDriveSenseT(FDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetDriveSenseT(var FDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadRangeT(var pTMin: Double; var pTMax: Double): Integer; stdcall; external 'oasis4i.dll'

///////////////////////////////////////////////////////////////////////////////
// S Axis
///////////////////////////////////////////////////////////////////////////////
function  OI_ReadS( var pdPos: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetPositionS( dPos: Double): Integer; stdcall; external 'oasis4i.dll'
function  OI_MoveToS(dPos: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepS(dDistance: Double; nWait: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadStatusS(var pnStatus: WORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetRampS(nRamp: Integer): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetRampS(var pnRamp: Integer): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetCruiseS(nCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetCruiseS(var pnCruise: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_HaltS(): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetStepSizeS(var pdStepSize: Double): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetStepSizeS(dStepSize: Double): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetOriginS(): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetSpeedS( var pdSpeed: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_SelectSpeedS( dFmmPerSec: Double; nFlags: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_LookupSpeedS( nCruise: Integer; var pdSpeed: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ClearUserLimitsS(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetDriveSenseS(FDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetDriveSenseS(var FDir: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadRangeS(var pTMin: Double; var pTMax: Double): Integer; stdcall; external 'oasis4i.dll'

///////////////////////////////////////////////////////////////////////////////
// Filter
///////////////////////////////////////////////////////////////////////////////
function	OI_SetFilterCount( nFilters: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetFilterCount( var pnFilters: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_MoveToFilter( nPosition, nWait: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetFilterPosition( var pnPosition: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_InitFilterChanger( nMethod: Integer; dUnitsPerRev: double ): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetFilterHomeOffset( dHomeOffset: double ): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetFilterHomeOffset( var dHomeOffset: double ): Integer; stdcall; external 'oasis4i.dll'
function	OI_WaitForStoppedFilter(): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetFilterName( nPosition: Integer; szBuffer: PChar ): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetFilterName( nPosition: Integer; szBuffer: PChar; nBufferLen: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetFilterDescription( nPosition: Integer; szBuffer: PChar ): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetFilterDescription( nPosition: Integer; szBuffer: PChar; nBufferLen: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_ReadFilterHomeInfo( var lpbHomeFound: BOOL; var pdHomeLeft: double; var pdHomeRight: double ): Integer; stdcall; external 'oasis4i.dll'
function	OI_ClearFilterHomeInfo(): Integer; stdcall; external 'oasis4i.dll'
function	OI_ReadFilterChangerInfo( var pdStepsPerRev: double; var pdFilterSpacing: double ): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetFilterOffset( nPosition: Integer; dOffset: Double ): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetFilterOffset( nPosition: Integer; var pdOffset: Double ): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetFilterLocation( nPosition: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_SelectFilterChanger( nChanger: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterChanger( var pnChanger: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterChangerCount( var pnChangers: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterChangerInfo( nChanger: Integer; var pnCard: Integer; var pnAxisID: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetFilterChangerInfo( nChanger, nCard, nAxisID: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_IsFilterChangerDetected( nChanger: Integer; var pbDetected: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetFilterChangerConfig( nChanger, nControl: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterChangerConfig( nChanger: Integer; var pnControl: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetFilterChangerCruise( nChanger, nCruise: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterChangerCruise( nChanger: Integer; var pnCruise: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetFilterChangerRamp( nChanger, nRamp: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterChangerRamp( nChanger: Integer; var pnRamp: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetFilterChangerType( nChanger, nType: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterChangerType( nChanger: Integer; var pnType: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetFilterCountEx(  nChanger: Integer; nFilters: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterCountEx(  nChanger: Integer; var pnFilters: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_MoveToFilterEx( nChanger: Integer; nPosition: Integer; nWait: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterPositionEx(  nChanger: Integer; var pnPosition: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_InitFilterChangerEx(  nChanger: Integer; nMethod: Integer; dUnitsPerRev:Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterChangerTypeCount( nChanger: Integer; var pnTypeCount: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFilterChangerTypeInfo(nChanger: Integer; nType: Integer; szName: PChar; nNameBuffLength: Integer ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetShutter( nPosition: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetShutter( var pnPosition: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetShutterMulti( nStates, nStateMask: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetShutterMulti( var pnStates: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetShutterEx( var lpbShutters: BOOL; var lpwValues: WORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetShutterEx( var pwRegister: WORD; var lpsiShutters: SHUTTERINFO; var pnShutterCount: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetShutterPolarity( nShutter, nReversed: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetShutterPolarity( nShutter: Integer; var pnReversed: Integer ): Integer; stdcall; external 'oasis4i.dll';
    
///////////////////////////////////////////////////////////////////////
// Changer
function	OI_GetContrastModeCount( var pnModes: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetContrastMode( var pnMode: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetContrastMode( nMode, nWait: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetContrastModeName( nMode: Integer; szName: PChar; nLen: Integer ): Integer; stdcall; external 'oasis4i.dll';

function	OI_ChangerGetCount( var pnChangers: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerSetController( nChanger, nController: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerConfigure( nChanger, nController, nComponent, nOption: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerGetConfiguration( nChanger: Integer; var pnController: Integer; var pnComponent: Integer; var pnOption: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerGetName( nChanger: Integer; szBuff: PChar; nBuffLen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerSetName( nChanger: Integer; szBuff: PChar ): Integer; stdcall; external 'oasis4i.dll';

function	OI_ChangerGetComponentCount( nChanger: Integer; var pnSubComponentCount: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerGetComponentName( nChanger, nComponent: Integer; szBuff: PChar; nBuffLen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerSelectComponent(  nChanger, nComponent: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerGetSelectedComponent( nChanger: Integer; var pnComponent: Integer ): Integer; stdcall; external 'oasis4i.dll';

function	OI_ChangerGetPositionName( nChanger, nPos: Integer; szBuff: PChar; nBuffLen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerGetPositionCount( nChanger: Integer; var pnCount: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerGetPositionRange( nChanger: Integer; var pnMin: Integer; var pnMax: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerMoveTo( nChanger, nPos, nWait: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerReadPosition( nChanger: Integer; var pnPos: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerIsMoving( nChanger: Integer; var pbMoving: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerInit( nChanger: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ChangerOpen(nChanger: Integer ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////////////
// Autofocus
///////////////////////////////////////////////////////////////////////////////
function  OI_AutoFocus(): Integer; stdcall; external 'oasis4i.dll';
function  OI_AutoFocusEx( Range: Double; Speed, Tolerance: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_AutoFocus_Step( Range: Double; Speed, Tolerance: Integer; StepSize: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_AutoFocus_Fine( Range: Double; nSamples: Integer; StepSize: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAutoFocus( Range: Double; Speed, Tolerance: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAutoFocus( var Range: Double; var Speed, Tolerance: Integer ): Integer; stdcall; external 'oasis4i.dll';
function  OI_SetAutoFocusThreshold(nThresh: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetAutoFocusThreshold(var nThresh: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadFocusScore(var dScore: Double): Integer; stdcall; external 'oasis4i.dll';
function  OI_ReadFocusProfile(var dScores, dPositions: Double; ArraySize: Integer; var Samples: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_WaitForAutoFocus(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetVideoWindow( XStart, XStop, YStart, YStop: Integer): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetVideoWindow( var XStart, XStop, YStart, YStop: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAutoFocusEx( dRange: Double; nSpeed, nTolerance: Integer; dStepSize:Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAutoFocusEx( var pdRange: Double; var pnSpeed, pnTolerance: Integer; var pdStepSize: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetFineFocusSamples( nSamples: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetFineFocusSamples( var pnSamples: Integer ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////////////
// Video
///////////////////////////////////////////////////////////////////////////////
function  OI_SetVideoSettings(nEvenPhase, nEvenThreshold, nOddPhase, nOddThreshold: Integer): Integer; stdcall; external 'oasis4i.dll'
function  OI_ReadVideoData(var nStatus: Integer; var pdwArea: DWORD; var pwMaxChord: WORD; var pwMaxGradient: WORD): Integer; stdcall; external 'oasis4i.dll'
function	OI_ReadVideoResults( nMode: Integer; var pdwArea: DWORD; var pwMaxChord: WORD): Integer; stdcall; external 'oasis4i.dll'
function	OI_ReadVideoResultsEx( nMode: Integer; var pdwArea: DWORD; var pwMaxChord: WORD; var pwMaxGradient: WORD): Integer; stdcall; external 'oasis4i.dll'
function	OI_ReadVideoHistogram( var pdwHisto: DWORD; nRes: Integer ): Integer; stdcall; external 'oasis4i.dll'
function	OI_SetCameraSyncMode(wMode, wField: WORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetCameraSyncMode(var pwMode: WORD; var pwField: WORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetDC1Registers( var pwRegs: WORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetDC1Registers( var pwRegs: WORD ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetDigitalAutofocus(  bEnable: BOOL; wIntervalMillSec: WORD; nPulseMillSec: Short ): Integer; stdcall; external 'oasis4i.dll'
function	OI_GetDigitalAutofocus( var pbEnable: BOOL; var pwIntervalMillSec: WORD; var pnPulseMillSec: Short ): Integer; stdcall; external 'oasis4i.dll'


///////////////////////////////////////////////////////////////////////
// File I/O
///////////////////////////////////////////////////////////////////////////////
function	OI_SaveSettings(sFile: PChar): Integer; stdcall; external 'oasis4i.dll';
function	OI_LoadSettings(sFile: PChar): Integer; stdcall; external 'oasis4i.dll';
function	OI_SavePositions(sFile: PChar): Integer; stdcall; external 'oasis4i.dll';
function	OI_LoadPositions(sFile: PChar): Integer; stdcall; external 'oasis4i.dll';


// Other Functions

function  OI_HaltAllAxes(): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////
// Joystick
function  OI_SetJoystickEnabled( bXEnabled, bYEnabled, bZEnabled: BOOL): Integer; stdcall; external 'oasis4i.dll';
function  OI_GetJoystickEnabled( var bXEnabled, bYEnabled, bZEnabled: BOOL): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetJoystickSense( nXSense, nYSense, nZSense: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetJoystickSense( var pnXSense, pnYSense, pnZSense: Integer ): Integer; stdcall; external 'oasis4i.dll';


function		OI_SetJoystickSettings(  wZDeviceSelect: WORD;
                  var pwJoySensitivities: WORD;
                  var pwDigiSensitivities: WORD;
                  wMicPassThrough: WORD;
                  var pwJoyButtons: WORD;
                  var pwSmartMoveButtons: WORD
              ): Integer; stdcall; external 'oasis4i.dll';
function		OI_GetJoystickSettings( var pwZDeviceSelect: WORD;
                  var pwJoySensitivities: WORD;
                  var wDigiSensitivities: WORD;
                  var pwMicPassThrough: WORD;
                  var pwJoyButtons: WORD;
                  var pwSmartMoveButtons: WORD
              ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetVideoTimeout( dwMSecs: DWORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetVideoTimeout(var lpdwMSecs: DWORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAutoFocusTimeout( dwMSecs: DWORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAutoFocusTimeout(var lpdwMSecs: DWORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetMoveTimeout( dwMSecs: DWORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetMoveTimeout(var lpdwMSecs: DWORD ): Integer; stdcall; external 'oasis4i.dll';

///////////////////////////////////////////////////////////////////////
// Error
function	OI_GetLastError( var pnCmd: Integer; var pnRetCode: Integer; szDesc: PChar; nLen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_EnableMsgReportDlg( bEnabled: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ShowMessageDlg(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetMessageDlgText( szMsg: PChar ): Integer; stdcall; external 'oasis4i.dll';
function	OI_HideMessageDlg(): Integer; stdcall; external 'oasis4i.dll';
function	OI_CloseMessageDlg(): Integer; stdcall; external 'oasis4i.dll';

function	OI_ShowLogWindow(): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetLoggingLevel( iLevel: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetLoggingLevel( var iLevel: Integer ): Integer; stdcall; external 'oasis4i.dll';


// Low-level I/F
function	OI_ReadDataMemory(Addr: WORD; var pData: WORD; nDataLen: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_WriteDataMemory(Addr: WORD; var pData: WORD; nDataLen: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadDataMemoryDWord(Addr: WORD; var pData: WORD; nDataLen: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_WriteDataMemoryDWord(Addr: WORD; var pData: WORD; nDataLen: Integer): Integer; stdcall; external 'oasis4i.dll';
function	OI_DSPCommand(CmdID: WORD): Integer; stdcall; external 'oasis4i.dll';

// Conversion
function	OI_MicronsToStepsX(dMicronVal: Double; var pSteps: DWORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_MicronsToStepsY(dMicronVal: Double; var pSteps: DWORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_MicronsToStepsZ(dMicronVal: Double; var pSteps: DWORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_MicronsToStepsF(dMicronVal: Double; var pSteps: DWORD): Integer; stdcall; external 'oasis4i.dll';
function	OI_AbsoluteToMicronsX( dwSteps: DWORD; var pdMicrons: double): Integer; stdcall; external 'oasis4i.dll';
function	OI_AbsoluteToMicronsY( dwSteps: DWORD; var pdMicrons: double): Integer; stdcall; external 'oasis4i.dll';
function	OI_AbsoluteToMicronsZ( dwSteps: DWORD; var pdMicrons: double): Integer; stdcall; external 'oasis4i.dll';
function	OI_AbsoluteToMicronsF( dwSteps: DWORD; var pdMicrons: double): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepsToMicronsX(dwSteps: DWORD; var pdMicrons: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepsToMicronsY(dwSteps: DWORD; var pdMicrons: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepsToMicronsZ(dwSteps: DWORD; var pdMicrons: Double): Integer; stdcall; external 'oasis4i.dll';
function	OI_StepsToMicronsF(dwSteps: DWORD; var pdMicrons: Double): Integer; stdcall; external 'oasis4i.dll';

function	OI_ReadCounters( var lpdwX: DWORD; var lpdwY: DWORD; var lpdwZ: DWORD; var lpdwF: DWORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadCountersEx( var lpdwDSP: DWORD; var lpdwEncoders: DWORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetCountersEx( var lpdwDSP: DWORD; var lpdwEncoders: DWORD ): Integer; stdcall; external 'oasis4i.dll';

// Simulation
function	OI_SimSetRangeXY( XRange, YRange: Double): Integer; stdcall; external 'oasis4i.dll';


///////////////////////////////////////////////////////////////////////
// I/O
function	OI_WriteIO( byVal: BYTE ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadIO( var lpbyVal: BYTE ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadInputPorts( var lpbyVal: BYTE ): Integer; stdcall; external 'oasis4i.dll';

function	OI_SetDAC( wLoadDac1, wDac1Val, wLoadDac2, wDac2Val, wLoadDac3, wDac3Val, wLoadDac4, wDac4Val: WORD ): Integer; stdcall; external 'oasis4i.dll';
function	OI_ReadDAC( var pwValuesArray: WORD ): Integer; stdcall; external 'oasis4i.dll';

function	OI_ReadIOEx( iCard: Integer; var pwVal: WORD ): Integer; stdcall; external 'oasis4i.dll';


////////////////////////////////////////////////////////
// Turret
function	OI_SelectLensByMag( dLensMag: Double; var pbFound: BOOL ): Integer; stdcall; external 'oasis4i.dll';
function	OI_HaltTurret(): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetLensCount( var pnLenses: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetLensPos( var pnPos: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetLensMicroStepPos( nPos: Integer; var pnPos: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_MoveToLens( nPos: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetLensMag( nPos: Integer; var pdMag: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetLensName( nPos: Integer; szName: PChar; nLen: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetLensNA( nPos: Integer; var pdNA: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetLensMag( nPos: Integer; dMag: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetLensName( nPos: Integer; szName: PChar ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetLensNA( nPos: Integer; dNA: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetLensCount( nLenses: Integer ): Integer; stdcall; external 'oasis4i.dll';
function	OI_InitTurret(
  nMethod: Integer; // type of init
  nLenses: Integer; // how many lenses
  dUnitsPerRev: Double; // how many units per rev, user init?
  dFirstLensOffset: Double // the offset from the home or min limit to first lens
): Integer; stdcall; external 'oasis4i.dll';


////////////////////////////////////////////////////////
// Lamp
function	OI_SetLamp( nChan: Integer; dPercent: Double ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetLamp( nChan: Integer; var pdPercent: Double ): Integer; stdcall; external 'oasis4i.dll';

{
////////////////////////////////////////////////////////
// Extras
function	OI_SetTopLens( int nPos ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetTopLens( int* pnPos ): Integer; stdcall; external 'oasis4i.dll';
function	OI_SetAperture( int nAperture, double dPos ): Integer; stdcall; external 'oasis4i.dll';
function	OI_GetAperture( int nAperture, double* pdPos ): Integer; stdcall; external 'oasis4i.dll';
}


implementation

end.

