Attribute VB_Name = "oasis4i"
Option Explicit

'///////////////// OI DLL CONSTANTS /////////////////

'///////////////////////////////////////////
'// Return Codes
'///////////////////////////////////////////
Global Const OI_OK = 0
Global Const OI_FAILED = 1
Global Const OI_ABORT = 2
Global Const OI_NOHARDWARE = 4
Global Const OI_TIMEOUT = 8
Global Const OI_INVALIDARG = 16
Global Const OI_HARDWAREBUSY = 32
Global Const OI_ACCESSDENIED = 64
Global Const OI_NOTSUPPORTED = 128
Global Const OI_ILLEGALAXIS = 256
Global Const OI_INVALIDCONFIG = 512
Global Const OI_MAXMOVEFAIL = 1024

'///////////////////////////////////////////
'// Axes IDs
'///////////////////////////////////////////
Global Const OI_XAXIS = 1
Global Const OI_YAXIS = 2
Global Const OI_ZAXIS = 3
Global Const OI_FAXIS = 4
Global Const OI_TAXIS = 5

'///////////////////////////////////////////
'// Axis Types (reserved)
'///////////////////////////////////////////
Global Const OI_TYPE_NOT_FITTED = 0
Global Const OI_TYPE_STEPPER = 1
Global Const OI_TYPE_DC = 2
Global Const OI_TYPE_SIMULATED = 3

'///////////////////////////////////////////
'// Init Methods (reserved)
'///////////////////////////////////////////
Global Const OI_INITBY_SWITCH = 0
Global Const OI_INITBY_MANUAL = 1

'///////////////////////////////////////////
'// Hardware Modes
'///////////////////////////////////////////
Global Const OI_SIM = 0
Global Const OI_OASIS = 1
Global Const OI_LEICA_DM = 10
Global Const OI_LEICA_DM2 = 11
Global Const OI_LEICA_MZ = 12
Global Const OI_OLYMPUS_BX = 20
Global Const OI_OLYMPUS_IX = 21
Global Const OI_NAVITAR = 50
Global Const OI_OPTEM = 51

'///////////////////////////////////////////
'// Status Codes
'///////////////////////////////////////////
Global Const S_LIMIT_PHY_NEG = &H1
Global Const S_LIMIT_USR_NEG = &H2
Global Const S_LIMIT_PHY_POS = &H8
Global Const S_LIMIT_USR_POS = &H4
Global Const S_LIMIT_USR_NEG_SET = &H10
Global Const S_LIMIT_USR_POS_SET = &H20
Global Const S_INITIALIZED = &H40
Global Const S_DIRECTION = &H80
Global Const S_MOVING = &H100
Global Const S_MOTOR_DETECTED = &H8000

'///////////////////////////////////////////
'// PCB STATUS BITS
'/*
'Bit meaning
'----------------
'31  Reserved
'30  Reserved
'29  Reserved
'28  Reserved
'27  Reserved
'26  Reserved
'25  Reserved
'24  Reserved
'23  Reserved
'22  Reserved
'21  Reserved
'20  Reserved
'19  Flash_user_OK       ( 1 = Flash user area checksum OK )
'18  Flash_OI_OK         ( 1 = Flash OI area checksum OK )
'17  Reserved
'16  Joystick_detect     ( 1 = Joystick unit fitted )
'15  Reserved
'14  Trackball_detect        ( 1 = Serial device is Kensington Trackball 5)
'13  Mouse_detect            ( 1 = Serial device is standard 2-button mouse)
'12  Serial_Device_detect        ( 1 = Serial device detected on RS232_0)
'11  Camera_type         ( 1 = Colour, 0 = Mono )
'10  Camera_frequency        ( 1 = 50 Hz, 0 = 60 Hz )
'9   Camera_channel      ( 1 = Channel 3, 0 = channel 0 (default))
'8   Camera_detect       ( 1 = Camera input detected )
'7   Video_Encoder_OK        ( 1 = Encoder configured OK )
'6   Autofocus_Module_type_1 ( 2 bit code indicating module type )
'5   Autofocus_Module_type_0 ( 2 bit code indicating module type )
'4   Autofocus_Module_fitted ( 1 = Module Detected )
'3   ADC_Analogue_input_X    ( 1 = ADC zero (correct) at switch on )
'2   ADC_Analogue_input_Y    ( 1 = ADC zero (correct) at switch on )
'1   PCB_Temperature     ( 1 = Temperature too high )
'0   Motor_volts_OK      ( 1 = Motor supply >= 10V i.e. OK )
'*/
'///////////////////////////////////////////
Global Const S_PCB_MOTOR_VOLTS_OK = &H1
Global Const S_PCB_TEMP_OK = &H2
Global Const S_PCB_ADC_YIN_OK = &H4
Global Const S_PCB_ADC_XIN_OK = &H8
Global Const S_PCB_AF_FITTED = &H10
Global Const S_PCB_AF_TYPE0 = &H20
Global Const S_PCB_AF_TYPE1 = &H40
Global Const S_PCB_VIDEO_ENCODER_OK = &H80
Global Const S_PCB_CAMERA_DETECTED = &H100
Global Const S_PCB_CAMERA_CHANNEL = &H200
Global Const S_PCB_CAMERA_FREQ = &H400
Global Const S_PCB_CAMERA_TYPE = &H800
Global Const S_PCB_SERIAL_DEV_DETECTED = &H1000
Global Const S_PCB_MOUSE_DETECTED = &H2000
Global Const S_PCB_TRACKBALL_FITTED = &H4000
'//      reserved                    &H8000
Global Const S_PCB_JOYSTICK_FITTED = &H10000
'//      reserved                    &H20000
Global Const S_PCB_FLASH_OI_OK = &H40000
Global Const S_PCB_FLASH_USER_OK = &H80000


'///////////////////////////////////////////
'// Range constants
'///////////////////////////////////////////
Global Const OI_CRUISE_MIN = 0
Global Const OI_CRUISE_MAX = 511
Global Const OI_RAMP_MIN = 0
Global Const OI_RAMP_MAX = 3
Global Const OI_DRIVE_SPEED_MIN = -4096
Global Const OI_DRIVE_SPEED_MAX = 4096


'////////////////////////////////////////////////////////
'// Filter initialization methods
'////////////////////////////////////////////////////////
Global Const OI_FILTER_INIT_HOME = 0
Global Const OI_FILTER_INIT_LIMITS = 1
Global Const OI_FILTER_INIT_USER = 2

'////////////////////////////////////////////////////////
'// OI-SC4 Shutter Controller masks
'////////////////////////////////////////////////////////
Global Const SHUTTER1 = 1
Global Const SHUTTER2 = 2
Global Const SHUTTER3 = 4
Global Const SHUTTER4 = 8

'///////////////////////////////////////////////////////////////////////
'// Hardware defs
Declare Function OI_Open Lib "oasis4i.dll" () As Long
Declare Function OI_Close Lib "oasis4i.dll" () As Long
Declare Function OI_GetDriverOpen Lib "oasis4i" (bOpen As Long) As Long

Declare Function OI_SetHardwareMode Lib "oasis4i" (ByVal nMode As Long) As Long
Declare Function OI_GetHardwareMode Lib "oasis4i" (pnMode As Long) As Long

Declare Function OI_SetAutoFocusHWMode Lib "oasis4i" (ByVal nMode As Long) As Long
Declare Function OI_GetAutoFocusHWMode Lib "oasis4i" (pnMode As Long) As Long

Declare Function OI_GetAFFitted Lib "oasis4i" (pbFitted As Long) As Long
Declare Function OI_SetAFFitted Lib "oasis4i" (ByVal bFitted As Long) As Long

Declare Function OI_ReadPCBStatus Lib "oasis4i" (lpdwHWState As Long) As Long
Declare Function OI_ReadPCBTemperature Lib "oasis4i" (dTempC As Double) As Long
Declare Function OI_ReadADCValues Lib "oasis4i" (pwValArray As Integer) As Long

Declare Function OI_CountCards Lib "oasis4i" (pnFound As Long) As Long

'///////////////////////////////////////////////////////////////////////
'// Version functions
Declare Function OI_GetDriverVersion Lib "oasis4i" (ByVal pVersion As String, ByVal nStringLen As Long) As Long
Declare Function OI_ReadPCBID Lib "oasis4i" (ByVal pIDBuffer As String, ByVal nStringLen As Long) As Long
Declare Function OI_ReadPCBVersion Lib "oasis4i" (ByVal pVersion As String, ByVal nStringLen As Long) As Long

'///////////////////////////////////////////////////////////////////////
'// General, Single Axis
Declare Function OI_GetTotalAxisCount Lib "oasis4i" (pnAxisCount As Long) As Long
Declare Function OI_GetAxisEnabled Lib "oasis4i" (ByVal AxisID As Long, pbEnabled As Integer) As Long
Declare Function OI_MoveAxis Lib "oasis4i" (ByVal AxisID As Long, ByVal dValue As Double, ByVal nWait As Long) As Long
Declare Function OI_ReadAxis Lib "oasis4i" (ByVal AxisID As Long, pdVdalue As Double) As Long
Declare Function OI_GetAxisRange Lib "oasis4i" (ByVal AxisID As Long, pdMin As Double, pdMax As Double) As Long
Declare Function OI_SetAxisStepSize Lib "oasis4i" (ByVal AxisID As Long, ByVal dStepSize As Double) As Long
Declare Function OI_GetAxisStepSize Lib "oasis4i" (ByVal AxisID As Long, pdStepSize As Double) As Long
Declare Function OI_SetAxisBacklash Lib "oasis4i" (ByVal AxisID As Long, ByVal bEnabled As Integer) As Long
Declare Function OI_GetAxisBacklash Lib "oasis4i" (ByVal AxisID As Long, pbEnabled As Integer) As Long
Declare Function OI_GetAxisCruise Lib "oasis4i" (ByVal AxisID As Long, pnCruise As Long) As Long
Declare Function OI_SetAxisCruise Lib "oasis4i" (ByVal AxisID As Long, ByVal nCruise As Long) As Long
Declare Function OI_GetAxisSense Lib "oasis4i" (ByVal AxisID As Long, pnSense As Long) As Long
Declare Function OI_SetAxisSense Lib "oasis4i" (ByVal AxisID As Long, ByVal nSense As Long) As Long
Declare Function OI_GetAxisRamp Lib "oasis4i" (ByVal AxisID As Long, pnRamp As Long) As Long
Declare Function OI_SetAxisRamp Lib "oasis4i" (ByVal AxisID As Long, ByVal nRamp As Long) As Long
Declare Function OI_DriveAxisContinuous Lib "oasis4i" (ByVal AxisID As Long, ByVal nSpeed As Long) As Long
Declare Function OI_StepAxis Lib "oasis4i" (ByVal AxisID As Long, ByVal dValue As Double, ByVal nWait As Long) As Long
Declare Function OI_SetAxisInitMethod Lib "oasis4i" (ByVal AxisID As Long, ByVal nMethod As Long) As Long
Declare Function OI_GetAxisInitMethod Lib "oasis4i" (ByVal AxisID As Long, pnMethod As Long) As Long
Declare Function OI_ReadAxisAtLimit Lib "oasis4i" (ByVal AxisID As Long, pbAtNegLimit As Integer, pbAtPosLimit As Integer) As Long
Declare Function OI_ReadAxisMoving Lib "oasis4i" (ByVal AxisID As Long, pbIsMoving As Integer) As Long
Declare Function OI_ReadAxisStatus Lib "oasis4i" (ByVal AxisID As Long, lpwStatus As Integer) As Long
Declare Function OI_SetAxisToDefaults Lib "oasis4i" (ByVal AxisID As Long) As Long
Declare Function OI_ReadAxisRampValue Lib "oasis4i" (ByVal AxisID As Long, ByVal wIndex As Integer, lpwInterval As Integer, lpwStepSize As Integer) As Long
Declare Function OI_HaltAxis Lib "oasis4i" (ByVal AxisID As Long) As Long
Declare Function OI_GetAxisMaxMove Lib "oasis4i" (ByVal AxisID As Long, lpdwValue As Long) As Long
Declare Function OI_GetAxisStepsPerRev Lib "oasis4i" (ByVal AxisID As Long, lpdwStepsPerRev As Long) As Long
Declare Function OI_MoveAxisAbs Lib "oasis4i" (ByVal AxisID As Long, ByVal lPos As Long, ByVal nWait As Long) As Long
Declare Function OI_StepAxisAbs Lib "oasis4i" (ByVal AxisID As Long, ByVal lSteps As Long, ByVal nWait As Long) As Long
Declare Function OI_ReadAxisAbs Lib "oasis4i" (ByVal AxisID As Long, plPos As Long) As Long
Declare Function OI_GetAxisRangeAbs Lib "oasis4i" (ByVal AxisID As Long, plMin As Long, plMax As Long) As Long
Declare Function OI_WaitForAxisStopped Lib "oasis4i" (ByVal AxisID As Long) As Long


'///////////////////////////////////////////////////////////////////////
'// Full axes
Declare Function OI_SetPositionXYZ Lib "oasis4i" (ByVal xpos As Double, ByVal ypos As Double, ByVal zpos As Double) As Long
Declare Function OI_MoveToXYZ Lib "oasis4i" (ByVal xpos As Double, ByVal ypos As Double, ByVal zpos As Double, ByVal nWait As Long) As Long
Declare Function OI_MoveToXYZ_Auto Lib "oasis4i" (ByVal xpos As Double, ByVal ypos As Double, ByVal zpos As Double, ByVal nWait As Long) As Long
Declare Function OI_ReadXYZ Lib "oasis4i" (xpos As Double, ypos As Double, zpos As Double) As Long
Declare Function OI_WaitForStoppedXYZ Lib "oasis4i" (ByVal xstop As Long, ByVal ystop As Long, ByVal zstop As Long) As Long
Declare Function OI_DriveContinuousXYZ Lib "oasis4i" (ByVal nXSpeed As Long, ByVal nYSpeed As Long, ByVal nZSpeed As Long) As Long

'///////////////////////////////////////////////////////////////////////
'// XY Stage conveniences: X and Y Axes combined
Declare Function OI_InitializeXY Lib "oasis4i" () As Long
Declare Function OI_SetPositionXY Lib "oasis4i" (ByVal xpos As Double, ByVal ypos As Double) As Long
Declare Function OI_SetOriginXY Lib "oasis4i" () As Long
Declare Function OI_ReadXY Lib "oasis4i" (xpos As Double, ypos As Double) As Long
Declare Function OI_MoveToXY Lib "oasis4i" (ByVal xpos As Double, ByVal ypos As Double, ByVal nWait As Long) As Long
Declare Function OI_MoveToXY_Auto Lib "oasis4i" (ByVal xpos As Double, ByVal ypos As Double, ByVal nWait As Long) As Long
Declare Function OI_StepXY Lib "oasis4i" (ByVal dXDistance As Double, ByVal dYDistance As Double, ByVal nWait As Long) As Long
Declare Function OI_StepX Lib "oasis4i" (ByVal dXDistance As Double, ByVal nWait As Long) As Long
Declare Function OI_StepY Lib "oasis4i" (ByVal dYDistance As Double, ByVal nWait As Long) As Long
Declare Function OI_ReadStatusXY Lib "oasis4i" (lpwXStatus As Integer, lpwYStatus As Integer) As Long
Declare Function OI_GetPitchXY Lib "oasis4i" (pdXPitch As Double, pdYPitch As Double) As Long
Declare Function OI_SetPitchXY Lib "oasis4i" (ByVal dXPitch As Double, ByVal dYPitch As Double) As Long
Declare Function OI_SetRampXY Lib "oasis4i" (ByVal nXRamp As Long, ByVal nYRamp As Long) As Long
Declare Function OI_GetRampXY Lib "oasis4i" (pnXRamp As Long, pnYRamp As Long) As Long
Declare Function OI_SetCruiseXY Lib "oasis4i" (ByVal nXCruise As Long, ByVal nYCruise As Long) As Long
Declare Function OI_GetCruiseXY Lib "oasis4i" (pnXCruise As Long, pnYCruise As Long) As Long
Declare Function OI_SetDriveSenseXY Lib "oasis4i" (ByVal nXDir As Long, ByVal nYDir As Long) As Long
Declare Function OI_GetDriveSenseXY Lib "oasis4i" (pnXDir As Long, pnYDir As Long) As Long
Declare Function OI_DriveContinuousXY Lib "oasis4i" (ByVal nXSpeed As Long, ByVal nYSpeed As Long) As Long
Declare Function OI_HaltXY Lib "oasis4i" () As Long
Declare Function OI_SetUserLimitsXY Lib "oasis4i" (ByVal dXMin As Double, ByVal dXMax As Double, ByVal dYMin As Double, ByVal dYMax As Double) As Long
Declare Function OI_GetUserLimitsXY Lib "oasis4i" (pdXMin As Double, pdXMax As Double, pdYMin As Double, pdYMax As Double) As Long
Declare Function OI_ReadLimitAlarmsXY Lib "oasis4i" (XNeg As Long, xpos As Long, YNeg As Long, ypos As Long) As Long

'///////////////////////////////////////////////////////////////////////
'// Z Axis
Declare Function OI_InitializeZ Lib "oasis4i.dll" (ByVal ZRangeAbove As Double, ByVal ZRangeBelow As Double) As Long
Declare Function OI_SetPositionZ Lib "oasis4i.dll" (ByVal zpos As Double) As Long
Declare Function OI_ReadZ Lib "oasis4i.dll" (zpos As Double) As Long
Declare Function OI_MoveToZ Lib "oasis4i.dll" (ByVal zpos As Double, ByVal nWait As Long) As Long
Declare Function OI_StepZ Lib "oasis4i.dll" (ByVal ZDistance As Double, ByVal nWait As Long) As Long
Declare Function OI_ReadStatusZ Lib "oasis4i" (lpwStatus As Integer) As Long
Declare Function OI_SetRampZ Lib "oasis4i" (ByVal nZRamp As Long) As Long
Declare Function OI_GetRampZ Lib "oasis4i" (pnZRamp As Long) As Long
Declare Function OI_SetCruiseZ Lib "oasis4i" (ByVal nZCruise As Long) As Long
Declare Function OI_GetCruiseZ Lib "oasis4i" (pnZCruise As Long) As Long
Declare Function OI_SetDriveSenseZ Lib "oasis4i" (ByVal nZDir As Long) As Long
Declare Function OI_GetDriveSenseZ Lib "oasis4i" (pnZDir As Long) As Long
Declare Function OI_DriveContinuousZ Lib "oasis4i" (ByVal nSpeed As Long) As Long
Declare Function OI_HaltZ Lib "oasis4i" () As Long
Declare Function OI_ReadRangeZ Lib "oasis4i" (pZMin As Double, pZMax As Double) As Long
Declare Function OI_SetUserLimitsZ Lib "oasis4i" (ByVal dZMin As Double, ByVal dZMax As Double) As Long
Declare Function OI_GetUserLimitsZ Lib "oasis4i" (pdZMin As Double, pdZMax As Double) As Long
Declare Function OI_SetFocusJoystick Lib "oasis4i" (ByVal nLeft As Long, ByVal nRight As Long) As Long
Declare Function OI_SetOriginZ Lib "oasis4i" () As Long

'///////////////////////////////////////////////////////////////////////
'// F Axis
Declare Function OI_InitializeF Lib "oasis4i" () As Long
Declare Function OI_InitializeFRange Lib "oasis4i" (ByVal FNegLimit As Double, ByVal FPosLimit As Double) As Long
Declare Function OI_SetPositionF Lib "oasis4i" (ByVal dFPos As Double) As Long
Declare Function OI_ReadF Lib "oasis4i" (pF As Double) As Long
Declare Function OI_MoveToF Lib "oasis4i" (ByVal f As Double, ByVal nWait As Long) As Long
Declare Function OI_StepF Lib "oasis4i" (ByVal FDistance As Double, ByVal nWait As Long) As Long
Declare Function OI_ReadStatusF Lib "oasis4i" (lpwStatus As Integer) As Long
Declare Function OI_SetRampF Lib "oasis4i" (ByVal nFRamp As Long) As Long
Declare Function OI_GetRampF Lib "oasis4i" (pnFRamp As Long) As Long
Declare Function OI_SetCruiseF Lib "oasis4i" (ByVal nFCruise As Long) As Long
Declare Function OI_GetCruiseF Lib "oasis4i" (pnFCruise As Long) As Long
Declare Function OI_SetDriveSenseF Lib "oasis4i" (ByVal nFDir As Long) As Long
Declare Function OI_GetDriveSenseF Lib "oasis4i" (pnFDir As Long) As Long
Declare Function OI_HaltF Lib "oasis4i" () As Long
Declare Function OI_ReadRangeF Lib "oasis4i" (pFMin As Double, pFMax As Double) As Long
Declare Function OI_GetStepSizeF Lib "oasis4i" (dStepSize As Double) As Long
Declare Function OI_SetStepSizeF Lib "oasis4i" (ByVal dStepSize As Double) As Long
Declare Function OI_WaitForStoppedF Lib "oasis4i" () As Long
Declare Function OI_SetUserLimitsF Lib "oasis4i" (ByVal pFMin As Double, ByVal pFMax As Double) As Long
Declare Function OI_GetUserLimitsF Lib "oasis4i" (pFMin As Double, pFMax As Double) As Long
Declare Function OI_SetOriginF Lib "oasis4i" () As Long

'///////////////////////////////////////////////////////////////////////
'// T Axis
Declare Function OI_InitializeT Lib "oasis4i" () As Long
Declare Function OI_InitializeTRange Lib "oasis4i" (ByVal dNegLimit As Double, ByVal dPosLimit As Double) As Long
Declare Function OI_SetPositionT Lib "oasis4i" (ByVal dPos As Double) As Long
Declare Function OI_ReadT Lib "oasis4i" (pdPos As Double) As Long
Declare Function OI_MoveToT Lib "oasis4i" (ByVal dPos As Double, ByVal nWait As Long) As Long
Declare Function OI_StepT Lib "oasis4i" (ByVal dDistance As Double, ByVal nWait As Long) As Long
Declare Function OI_ReadStatusT Lib "oasis4i" (lpwStatus As Integer) As Long
Declare Function OI_SetRampT Lib "oasis4i" (ByVal nRamp As Long) As Long
Declare Function OI_GetRampT Lib "oasis4i" (pnRamp As Long) As Long
Declare Function OI_SetCruiseT Lib "oasis4i" (ByVal nCruise As Long) As Long
Declare Function OI_GetCruiseT Lib "oasis4i" (pnCruise As Long) As Long
Declare Function OI_SetDriveSenseT Lib "oasis4i" (ByVal nDir As Long) As Long
Declare Function OI_GetDriveSenseT Lib "oasis4i" (pnDir As Long) As Long
Declare Function OI_HaltT Lib "oasis4i" () As Long
Declare Function OI_ReadRangeT Lib "oasis4i" (pdMin As Double, pdMax As Double) As Long
Declare Function OI_GetStepSizeT Lib "oasis4i" (dStepSize As Double) As Long
Declare Function OI_SetStepSizeT Lib "oasis4i" (ByVal dStepSize As Double) As Long
Declare Function OI_WaitForStoppedT Lib "oasis4i" () As Long
Declare Function OI_SetUserLimitsT Lib "oasis4i" (ByVal dMin As Double, ByVal dMax As Double) As Long
Declare Function OI_GetUserLimitsT Lib "oasis4i" (pdMin As Double, pdMax As Double) As Long
Declare Function OI_SetOriginT Lib "oasis4i" () As Long
Declare Function OI_ReadLimitAlarmsT Lib "oasis4i" (pnNeg As Long, pnPos As Long) As Long
Declare Function OI_SetPitchT Lib "oasis4i" (ByVal dPitchMM As Double) As Long
Declare Function OI_GetPitchT Lib "oasis4i" (pdPitchMM As Double) As Long
Declare Function OI_ReadMaxMoveT Lib "oasis4i" (lpdwSteps As Long, lpwDecel As Integer) As Long
Declare Function OI_GetSpeedT Lib "oasis4i" (pdSpeed As Double) As Long
Declare Function OI_SelectSpeedT Lib "oasis4i" (ByVal dFmmPerSec As Double, ByVal nFlags As Long) As Long
Declare Function OI_LookupSpeedT Lib "oasis4i" (ByVal nCruise As Long, pdSpeed As Double) As Long
Declare Function OI_ClearUserLimitsT Lib "oasis4i" () As Long

'///////////////////////////////////////////////////////////////////////
'// Autofocus
Declare Function OI_SetAutoFocus Lib "oasis4i" (ByVal dRange As Double, ByVal Speed As Long, ByVal Tolerance As Long) As Long
Declare Function OI_GetAutoFocus Lib "oasis4i" (pdRange As Double, Speed As Long, pnTolerance As Long) As Long
Declare Function OI_AutoFocus Lib "oasis4i" () As Long
Declare Function OI_AutoFocusEx Lib "oasis4i" (ByVal dRange As Double, ByVal Speed As Long, ByVal Tolerance As Long) As Long
Declare Function OI_AutoFocus_Step Lib "oasis4i" (ByVal dRange As Double, ByVal Speed As Long, ByVal Tolerance As Long, ByVal dStepSize As Double) As Long
Declare Function OI_SetAutoFocusThreshold Lib "oasis4i" (ByVal wThresh As Integer) As Long
Declare Function OI_GetAutoFocusThreshold Lib "oasis4i" (lpwThresh As Integer) As Long
Declare Function OI_ReadFocusScore Lib "oasis4i" (Score As Double) As Long
Declare Function OI_ReadFocusScoreEx Lib "oasis4i" (Score As Double, zpos As Double) As Long
Declare Function OI_ReadFocusProfile Lib "oasis4i" (pdArray As Double, pdZPos As Double, ByVal nSize As Long, pnSamples As Long) As Long
Declare Function OI_RequestAutoFocusStatus Lib "oasis4i" (Finished As Integer, Success As Integer, NumSamples As Integer) As Long
Declare Function OI_RequestFocusStatus Lib "oasis4i" (Status As Integer) As Long
Declare Function OI_WaitForAutoFocus Lib "oasis4i" () As Long

'///////////////////////////////////////////////////////////////////////
'// Video
Declare Function OI_SetVideoSettings Lib "oasis4i" (ByVal nEvenPhase As Long, ByVal nEvenThreshold As Long, ByVal nOddPhase As Long, ByVal nOddThreshold As Long) As Long
Declare Function OI_GetVideoSettings Lib "oasis4i" (nEvenPhase As Long, nEvenThreshold As Long, nOddPhase As Long, nOddThreshold As Long) As Long
Declare Function OI_ReadVideoData Lib "oasis4i" (nStatus As Integer, pdwArea As Long, pwMaxChord As Integer, pwMaxGradient As Integer) As Long
Declare Function OI_ReadVideoResults Lib "oasis4i" (ByVal nMode As Long, pdwArea As Long, pwMaxChord As Integer) As Long
Declare Function OI_ReadVideoResultsEx Lib "oasis4i" (ByVal nMode, pdwArea As Long, pwMaxChord As Integer, pwMaxGradient As Integer) As Long
Declare Function OI_ReadVideoResultsXYZF Lib "oasis4i" (ByVal nMode As Long, pdResults As Double, pdPositions As Double) As Long
Declare Function OI_ReadVideoResultsZ Lib "oasis4i" (ByVal nMode As Long, pdResults As Double, pdZPos As Double) As Long
Declare Function OI_ReadVideoResultsXY Lib "oasis4i" (ByVal nMode As Long, pdResults As Double, pdXPos As Double, pdYPos As Double) As Long
Declare Function OI_IsVideoDetected Lib "oasis4i" (bFound As Long) As Long
Declare Function OI_SetVideoWindow Lib "oasis4i" (ByVal nXStart As Long, ByVal nXStop As Long, ByVal nYStart As Long, ByVal nYStop As Long) As Long
Declare Function OI_GetVideoWindow Lib "oasis4i" (nXStart As Long, nXStop As Long, nYStart As Long, nYStop As Long) As Long

'///////////////////////////////////////////////////////////////////////
'// General stops
Declare Function OI_HaltAllAxes Lib "oasis4i" () As Long
Declare Function OI_EmergencyStopAll Lib "oasis4i" () As Long

'///////////////////////////////////////////////////////////////////////
'// Timeouts
Declare Function OI_SetVideoTimeout Lib "oasis4i" (ByVal dwMSecs As Long) As Long
Declare Function OI_GetVideoTimeout Lib "oasis4i" (lpdwMSecs As Long) As Long
Declare Function OI_SetAutoFocusTimeout Lib "oasis4i" (ByVal dwMSecs As Long) As Long
Declare Function OI_GetAutoFocusTimeout Lib "oasis4i" (lpdwMSecs As Long) As Long
Declare Function OI_SetMoveTimeout Lib "oasis4i" (ByVal dwMSecs As Long) As Long
Declare Function OI_GetMoveTimeout Lib "oasis4i" (lpdwMSecs As Long) As Long

'///////////////////////////////////////////////////////////////////////
'// File I/O
Declare Function OI_SaveSettings Lib "oasis4i" (ByVal sFile As String) As Long
Declare Function OI_LoadSettings Lib "oasis4i" (ByVal sFile As String) As Long
Declare Function OI_SavePositions Lib "oasis4i" (ByVal sFile As String) As Long
Declare Function OI_LoadPositions Lib "oasis4i" (ByVal sFile As String) As Long

'///////////////////////////////////////////////////////////////////////
'// Filter Changer
Declare Function OI_SetFilterCount Lib "oasis4i" (ByVal nFilters As Long) As Long
Declare Function OI_GetFilterCount Lib "oasis4i" (pnFilters As Long) As Long
Declare Function OI_DeleteFilter Lib "oasis4i" (ByVal nPosition As Long) As Long
Declare Function OI_MoveToFilter Lib "oasis4i" (ByVal nPosition As Long, ByVal nWait As Long) As Long
Declare Function OI_GetFilterPosition Lib "oasis4i" (pnPosition As Long) As Long
Declare Function OI_InitFilterChanger Lib "oasis4i" (ByVal nMethod As Long, ByVal dUnitsPerRev As Double) As Long
Declare Function OI_SetFilterHomeOffset Lib "oasis4i" (ByVal dOffset As Double) As Long
Declare Function OI_GetFilterHomeOffset Lib "oasis4i" (pdOffset As Double) As Long
Declare Function OI_WaitForStoppedFilter Lib "oasis4i" () As Long
Declare Function OI_SetFilterName Lib "oasis4i" (ByVal nPosition As Long, ByVal szBuffer As String) As Long
Declare Function OI_GetFilterName Lib "oasis4i" (ByVal nPosition As Long, ByVal szBuffer As String, ByVal nBufferLen As Long) As Long
Declare Function OI_SetFilterDescription Lib "oasis4i" (ByVal nPosition As Long, ByVal szBuffer As String) As Long
Declare Function OI_GetFilterDescription Lib "oasis4i" (ByVal nPosition As Long, ByVal szBuffer As String, ByVal nBufferLen As Long) As Long
Declare Function OI_ReadFilterHomeInfo Lib "oasis4i" (lpbHomeFound As Integer, pdHomeLeft As Double, pdHomeRight As Double) As Long
Declare Function OI_ReadFilterChangerInfo Lib "oasis4i" (pdUnitsPerRev As Double, pdFilterSpacing As Double) As Long
Declare Function OI_SetFilterOffset Lib "oasis4i" (ByVal nPosition As Long, ByVal dOffset As Double) As Long
Declare Function OI_GetFilterOffset Lib "oasis4i" (ByVal nPosition As Long, pdOffset As Double) As Long
Declare Function OI_SetFilterLocation Lib "oasis4i" (ByVal nPosition As Long) As Long
Declare Function OI_ClearFilterHomeInfo Lib "oasis4i" (void) As Long

Declare Function OI_SelectFilterChanger Lib "oasis4i" (ByVal nChanger As Long) As Long
Declare Function OI_GetFilterChanger Lib "oasis4i" (pnChanger As Long) As Long
Declare Function OI_GetFilterChangerCount Lib "oasis4i" (pnChangers As Long) As Long
Declare Function OI_GetFilterChangerInfo Lib "oasis4i" (ByVal nChanger As Long, pnCard As Long, pnAxisID As Long) As Long
Declare Function OI_SetFilterChangerInfo Lib "oasis4i" (ByVal nChanger As Long, ByVal nCard As Long, ByVal nAxisID As Long) As Long
Declare Function OI_IsFilterChangerDetected Lib "oasis4i" (ByVal nChanger As Long, pbDetected As Integer) As Long
Declare Function OI_SetFilterChangerConfig Lib "oasis4i" (ByVal nChanger As Long, ByVal nControl As Long) As Long
Declare Function OI_GetFilterChangerConfig Lib "oasis4i" (ByVal nChanger As Long, pnControl As Long) As Long

Declare Function OI_SetFilterChangerCruise Lib "oasis4i" (ByVal nChanger As Long, ByVal nCruise As Long) As Long
Declare Function OI_GetFilterChangerCruise Lib "oasis4i" (ByVal nChanger As Long, pnCruise As Long) As Long
Declare Function OI_SetFilterChangerRamp Lib "oasis4i" (ByVal nChanger As Long, ByVal nRamp As Long) As Long
Declare Function OI_GetFilterChangerRamp Lib "oasis4i" (ByVal nChanger As Long, pnRamp As Long) As Long

Declare Function OI_SetShutter Lib "oasis4i" (ByVal nPosition As Long, ByVal nShutter As Long) As Long
Declare Function OI_GetShutter Lib "oasis4i" (pnPosition As Long, ByVal nShutter As Long) As Long
Declare Function OI_SetShutterMulti Lib "oasis4i" (ByVal nStates As Long, ByVal nStateMask As Long) As Long
Declare Function OI_GetShutterMulti Lib "oasis4i" (pnStates As Long) As Long

'///////////////////////////////////////////////////////////////////////
'// Error
Declare Function OI_GetLastError Lib "oasis4i" (pnCmd As Long, pnRetCode As Long, ByVal szDesc As String, ByVal nLen As Long) As Long
Declare Function OI_EnableMsgReportDlg Lib "oasis4i" (ByVal bEnabled As Long) As Long
