///////////////////////////////////////////////////////////////////////
// OASIS4I.H : Exports for OASIS4I DLL
//
// Version 4.0
//
// Copyright (C) 2000-2012 Objective Imaging Ltd.
// All rights reserved.
//
///////////////////////////////////////////////////////////////////////

#ifndef _OASIS4I_H
#define _OASIS4I_H


#ifdef __cplusplus
extern "C" {            /* Assume C declarations for C++ */
#endif  /* __cplusplus */

#include "oi_const.h"

///////////////////////////////////////////////////////////////////////
// Hardware defs
OI_API  OI_Open(void);
OI_API  OI_Close(void);
OI_API	OI_OpenEx(int iReserved);
OI_API  OI_CloseEx(void);

OI_API	OI_GetDriverOpen(BOOL* bOpen);
OI_API	OI_GetUseCount( int* pnUsers );

OI_API	OI_SetHardwareMode(int nMode);
OI_API	OI_GetHardwareMode(int* pnMode);

OI_API	OI_GetHardwareModeCount( int* pnCount );
OI_API	OI_GetHardwareModeInfo( int nZeroBasedIndex, int* pnMode,  int* pnType, char* szName, int nStringLen );

OI_API	OI_SetAutoFocusHWMode(int nMode);
OI_API	OI_GetAutoFocusHWMode(int* pnMode);

OI_API  OI_GetAFFitted(BOOL* pbFitted);
OI_API	OI_IsModuleFitted( int nModule, LPBOOL pbFitted );

OI_API	OI_ReadPCBStatus(LPDWORD lpdwHWState);
OI_API	OI_ReadPCBStatusEx( LPWORD lpwExtendStatusWords );
OI_API	OI_ReadPCBType( int* pnType );
OI_API	OI_GetCardType( int nCard, int* pnType );
OI_API	OI_GetCardAxisCount( int nCard, int* pnAxisCount );

OI_API	OI_ReadPCBTemperature(double *dTempC);
OI_API	OI_ReadADCValues( LPWORD pwValArray );
OI_API	OI_ReadADCValuesEx( LPWORD pwValArray );

OI_API	OI_Configure( int nComponent, int nControl );
OI_API	OI_GetConfiguration( int nComponent, int *pnControl );
OI_API	OI_OpenComponent( int nComponent );
OI_API	OI_CloseComponent( int nComponent );
OI_API	OI_GetComponentStatus( int nComponent, LPDWORD lpdwStatus );
OI_API	OI_GetComponentName( int nComponent, LPSTR lpszName, int nNameLen );
OI_API	OI_InitComponent( int nComponent );

OI_API	OI_GetAvailControllerCount( int nComponent, int* pnCount );
OI_API	OI_GetControllerName( int nComponent, int nIndex, char* szName, int nStringLen, int* pnID );
OI_API	OI_GetControllerNameByID(int nComponent, int nID, char* szName, int nStringLen);
OI_API	OI_SetControllerName( int nComponent, int nIndex, char* szName);
OI_API	OI_SetControllerNameByID( int nComponent, int nID, char* szName);
OI_API	OI_GetControllerID( int nComponent, int nIndex, int* pnID );
OI_API	OI_GetControllerCapabilities( int nComponent, int nID, int* nCapabilities);

OI_API  OI_SetControllerPort( int nComponent, LPCTSTR szPort);
OI_API  OI_GetControllerPort( int nComponent, LPSTR szBuffer, int nBufferLen);
OI_API  OI_SetMainControllerPort(int iPortNum);
OI_API	OI_GetMainControllerPort(int* piPortNum);

OI_API	OI_SetAutoOpenExtDevice( BOOL bAutoOpen );
OI_API	OI_GetAutoOpenExtDevice( LPBOOL lpbAutoOpen );
OI_API	OI_OpenExtDevice( int iReserved );
OI_API	OI_SetAutoConnectOptions(DWORD dwOptions);
OI_API	OI_GetAutoConnectOptions(LPDWORD lpdwOptions);

OI_API	OI_SetDefaultWaitCursorEnabled( BOOL bEnabled );
OI_API	OI_GetDefaultWaitCursorEnabled( LPBOOL pbEnabled );

OI_API	OI_ResetHardware();
OI_API	OI_GetFlashCheckSum(LPWORD pwCheckSum);
OI_API  OI_EnableMotorPower(BOOL XYEnabled, BOOL ZFEnabled);
OI_API  OI_EnableMotorPowerEx(LPWORD pwMotors);

OI_API	OI_SetPitchFromFlashXYZ();
OI_API	OI_FlashReadAxisPitch( int AxisID, double *pdPitchMM );

OI_API	OI_GetLicenseInfo( int LicenseID, LPBYTE pbyInfo );
OI_API	OI_GetLicenseSourceID(char* szName, int nStringLen);

///////////////////////////////////////////////////////////////////////
// Leica AHM Specifics
OI_API	OI_SetAHMDelay(DWORD dwMSecs);
OI_API	OI_GetAHMDelay(LPDWORD lpdwMSecs);
OI_API	OI_SetAHMRootUnit(void* pRootUnit, int iFlags);

///////////////////////////////////////////////////////////////////////
// Multiple card support
OI_API	OI_CountCards( int* pnFound );
OI_API	OI_SelectCard( int nCard );
OI_API	OI_GetSelectedCard( int* pnCard );
OI_API	OI_ReadCardStatus(  int nCard, LPDWORD lpdwStatus );
OI_API	OI_SetMultiAxisMode( int nMode );
OI_API	OI_GetMultiAxisMode( int* pnMode );

///////////////////////////////////////////////////////////////////////
// Version functions
OI_API	OI_GetDriverVersion( LPSTR pVersion, int nStringLen );
OI_API	OI_ReadPCBID( LPSTR pIDBuffer, int nStringLen );
OI_API	OI_ReadPCBVersion( LPSTR pVersion, int nStringLen );
OI_API	OI_ReadSerialNum(int nCard, LPSTR szSerialNum, int nStringLen );
OI_API	OI_ReadPCBName( int nCard, LPSTR szName, int nStringLen );

///////////////////////////////////////////////////////////////////////
// General, Single Axis
OI_API	OI_GetTotalAxisCount( int* pnAxisCount );
OI_API	OI_GetAxisEnabled( int AxisID, BOOL *pbEnabled );
OI_API	OI_MoveAxis(int AxisID, double dValue, int nWait);
OI_API	OI_ReadAxis(int AxisID, double* pdVdalue);
OI_API	OI_SetAxisPosition(int AxisID, double dNewPos);
OI_API	OI_GetAxisRange(int AxisID, double* pdMin, double* pdMax);
OI_API	OI_SetAxisStepSize(int AxisID, double dStepSize);
OI_API	OI_GetAxisStepSize(int AxisID, double* pdStepSize);
OI_API	OI_SetAxisBacklash(int AxisID, BOOL bEnabled);
OI_API	OI_GetAxisBacklash(int AxisID, BOOL* pbEnabled);
OI_API  OI_GetAxisType(int AxisID, int* pnType);
OI_API  OI_SetAxisType(int AxisID, int nType);
OI_API  OI_GetAxisCruise(int AxisID, int* pnCruise);
OI_API  OI_SetAxisCruise(int AxisID, int nCruise);
OI_API  OI_GetAxisSense(int AxisID, int* pnSense);
OI_API  OI_SetAxisSense(int AxisID, int nSense);
OI_API  OI_GetAxisRamp(int AxisID, int* pnRamp);
OI_API  OI_SetAxisRamp(int AxisID, int nRamp);
OI_API  OI_DriveAxisContinuous(int AxisID, int nSpeed);
OI_API	OI_StepAxis(int AxisID, double dValue, int nWait);
OI_API	OI_SetAxisInitMethod(int AxisID, int nMethod);
OI_API	OI_GetAxisInitMethod(int AxisID, int *pnMethod);
OI_API	OI_ReadAxisAtLimit(int AxisID, BOOL* pbAtNegLimit, BOOL* pbAtPosLimit);
OI_API	OI_ReadAxisMoving(int AxisID, BOOL* pbIsMoving);
OI_API	OI_ReadAxisStatus(int AxisID, LPWORD lpwStatus);
OI_API	OI_SetAxisToDefaults(int AxisID);
OI_API	OI_ReadAxisRampValue(int AxisID, WORD wIndex, LPWORD lpwInterval, LPWORD lpwStepSize);
OI_API	OI_HaltAxis(int AxisID);
OI_API	OI_GetAxisMaxMove( int AxisID, LPDWORD lpdwValue );
OI_API	OI_GetAxisMaxMoveMicrons(int nCard, int AxisID, double* pdMicrons);
OI_API	OI_GetAxisStepsPerRev( int AxisID, LPDWORD lpdwStepsPerRev );
OI_API	OI_MoveAxisAbs(int AxisID, long lPos, int nWait);
OI_API	OI_StepAxisAbs(int AxisID, long lSteps, int nWait);
OI_API	OI_ReadAxisAbs(int AxisID, long *plPos);
OI_API	OI_GetAxisRangeAbs(int AxisID, long* plMin, long* plMax);
OI_API	OI_WaitForAxisStopped( int AxisID );
OI_API	OI_ClearAxisUserLimits( int AxisID );
OI_API	OI_SetAxisUserLimits( int AxisID, double dMin, double dMax );
OI_API	OI_GetAxisUserLimits( int AxisID, double* dMin, double* dMax );

OI_API	OI_SetAxisTravel(int AxisID, double dMin, double dMax);
OI_API	OI_GetAxisTravel(int AxisID, double* pdMin, double* pdMax);
OI_API	OI_InitAxisByLimits( int AxisID, double* pdMin, double* pdMax );
OI_API	OI_SetAxisInitOrigin( int AxisID, int iInitOriginDefinition );
OI_API	OI_GetAxisInitOrigin( int AxisID, int* piInitOriginDefinition );

OI_API	OI_SetAxisPitch( int AxisID, double dPitchMM );
OI_API	OI_GetAxisPitch( int AxisID, double* pdPitchMM );
OI_API	OI_LookupAxisSpeed( int AxisID, int nCruise, double* pdSpeed );
OI_API	OI_GetAxisEstMoveTime( int AxisID, double dDistance, double* dEstMsecs );

OI_API	OI_MoveAxisEx(int nCard, int AxisID, double dValue, int nWait);
OI_API	OI_ReadAxisEx(int nCard, int AxisID, double* pdVdalue);
OI_API	OI_StepAxisEx(int nCard, int AxisID, double dValue, int nWait);
OI_API	OI_ReadAxisStatusEx(int nCard, int AxisID, LPWORD lpwStatus);
OI_API  OI_DriveAxisContinuousEx(int nCard, int AxisID, int nSpeed);
OI_API	OI_WaitForAxisStoppedEx( int nCard, int AxisID );
OI_API	OI_SetAxisPitchEx( int nCard, int AxisID, double dPitchMM );
OI_API	OI_GetAxisPitchEx( int nCard, int AxisID, double* pdPitchMM );
OI_API	OI_HaltAxisEx(int nCard, int AxisID);
OI_API  OI_GetAxisCruiseEx(int nCard, int AxisID, int* pnCruise);
OI_API  OI_SetAxisCruiseEx(int nCard, int AxisID, int nCruise);
OI_API  OI_GetAxisRampEx(int nCard, int AxisID, int* pnRamp);
OI_API  OI_SetAxisRampEx(int nCard, int AxisID, int nRamp);
OI_API	OI_StepAxisAbsEx(int nCard, int AxisID, long lSteps, int nWait);
OI_API	OI_SetAxisPositionEx(int nCard, int AxisID, double dPosition);
OI_API	OI_GetAxisMaxMoveEx(int nCard, int AxisID, LPDWORD lpdwValue);

OI_API	OI_InitAxisToHome( int AxisID );
OI_API	OI_GetAxisHomeInfo( int AxisID, double* pUnitsPerRev );
OI_API	OI_ClearAxisHome( int AxisID );
OI_API	OI_ReadAxisHome( int AxisID, LPBOOL lpbHomeFound, double *pdHomeLeft, double *pdHomeRight );

///////////////////////////////////////////////////////////////////////
// Encoder support
OI_API	OI_GetAxisEncoderFitted( int AxisID, LPBOOL lpbFitted );
OI_API	OI_GetAxisEncoderEnabled( int AxisID, LPBOOL lpbEnabled, LPBOOL lpbAutoCorrect );
OI_API	OI_SetAxisEncoderEnabled( int AxisID, BOOL bEnabled, BOOL bAutoCorrect );
OI_API	OI_GetAxisEncoderStepSize( int AxisID, double *pdMicrons );
OI_API	OI_GetAxisEncoderFactor( int AxisID, int* piuStepsPerEncoder );

OI_API	OI_SetEncoderEnabledXY( BOOL bEnabledX, int nTolX, BOOL bEnabledY, int nTolY );
OI_API	OI_GetEncoderEnabledXY( LPBOOL pbEnabledX, int* pnTolX, LPBOOL pbEnabledY, int* pnTolY );
OI_API	OI_SetEncoderEnabledZ( BOOL bEnabled, int nTol);
OI_API	OI_GetEncoderEnabledZ( LPBOOL pbEnabled, int* pnTol);
OI_API	OI_SetEncoderEnabledF( BOOL bEnabled, int nTol);
OI_API	OI_GetEncoderEnabledF( LPBOOL pbEnabled, int* pnTol);

OI_API	OI_SetEncoderModule( WORD wOutputPulseWidth_usec, 
							WORD wComparitor1On, DWORD dwComparitor1Value, 
							WORD wComparitor2On, DWORD dwComparitor2Value, 
							WORD wReserved, DWORD dwReserved, 
							WORD wReserved2, DWORD dwReserved2, 
							WORD wOptions );
		
OI_API	OI_ReadEncoderModule( LPWORD pwInfo, LPWORD pwOptions, LPWORD pwOutputPulseWidth_usec,
							LPDWORD pdwComparitor1,
							LPDWORD pdwComparitor2,
							LPDWORD pdwReserved,
							LPDWORD pdwReserved2);

OI_API	OI_ReadEncoderValues( double* pdX, double* pdY, double* pdZ, double* pdF );

OI_API	OI_SetEncoderClosedLoopResponseXYZ( int nResponseX, int nResponseY, int nResponseZ );
OI_API	OI_GetEncoderClosedLoopResponseXYZ( int* pnResponseX, int* pnResponseY, int* pnResponseZ );

// Glide trigger comparators
OI_API	OI_SetTriggerComparator( int iPulseWidth, BOOL bUpdate1, int iCounterValue1, BOOL bUpdate2, int iCounterValue2, unsigned int uRegisterA, unsigned int uRegisterD );
OI_API	OI_GetTriggerComparator( int* piPulseWidth, int* piCounterValue1, int* piCounterValue2, unsigned int* puRegisterA, unsigned int* puRegisterD );

///////////////////////////////////////////////////////////////////////
// Full axes
OI_API	OI_SetPositionXYZ(double XPos, double YPos, double ZPos);
OI_API	OI_MoveToXYZ(double dX, double dY, double dZ, int nWait);
OI_API	OI_MoveToXYZ_Auto(double dX, double dY, double dZ, int nWait);
OI_API	OI_ReadXYZ(double* pdX, double* pdY, double* pdZ);
OI_API	OI_WaitForStoppedXYZ(int xstop, int ystop, int zstop);
OI_API	OI_DriveContinuousXYZ(int nXSpeed, int nYSpeed, int nZSpeed);
OI_API	OI_ReadMaxMoveXYZ(LPDWORD lpdwXSteps, LPWORD lpwXDecel, LPDWORD lpdwYSteps, LPWORD lpwYDecel, LPDWORD lpdwZSteps, LPWORD lpwZDecel );
OI_API	OI_StepAxis_Abs( int AxisID, DWORD dwSteps, int nWait );
OI_API	OI_StepXYZF_Abs( long XStep, long YStep, long ZStep, long FStep, int nWait);
OI_API	OI_ReadXYZF_Abs( LPDWORD pdwX, LPDWORD pdwY, LPDWORD pdwZ, LPDWORD pdwF );
OI_API	OI_ReadStatusXYZ( LPWORD pwX, LPWORD pwY, LPWORD pwZ );
OI_API	OI_MoveToXYZ_Triggered( double dX, double dY, double dZ, int nSyncSource, int nSyncPolarity);

///////////////////////////////////////////////////////////////////////
// XY Stage conveniences: X and Y Axes combined
OI_API  OI_InitializeXY(void);
OI_API	OI_SetPositionXY(double XPos, double YPos);
OI_API	OI_SetOriginXY(void);
OI_API  OI_ReadXY(double* pdX, double* pdY);
OI_API  OI_MoveToXY(double dX, double dY, int nWait);
OI_API	OI_MoveToXY_Auto(double dX, double dY, int nWait);
OI_API	OI_StepXY(double dXDistance, double dYDistance, int Wait);
OI_API	OI_StepX(double dXDistance, int nWait);
OI_API  OI_StepY(double dYDistance, int nWait);
OI_API  OI_ReadStatusXY(LPWORD lpwXStatus, LPWORD lpwYStatus);
OI_API  OI_GetPitchXY(double* pdXPitch, double* pdYPitch);
OI_API  OI_SetPitchXY(double dXPitch, double dYPitch);
OI_API	OI_SetRampXY(int nXRamp, int nYRamp);
OI_API	OI_GetRampXY(int* pnXRamp, int* pnYRamp);
OI_API	OI_SetCruiseXY(int nXCruise, int nYCruise);
OI_API	OI_GetCruiseXY(int* pnXCruise, int* pnYCruise);
OI_API	OI_SetDriveSenseXY(int nXDir, int nYDir);
OI_API	OI_GetDriveSenseXY(int* pnXDir, int* pnYDir);
OI_API	OI_DriveContinuousXY(int nXSpeed, int nYSpeed);
OI_API	OI_HaltXY(void);
OI_API	OI_SetUserLimitsXY(double dXMin, double dXMax, double dYMin, double dYMax);
OI_API	OI_GetUserLimitsXY(double* pdXMin, double* pdXMax, double* pdYMin, double* pdYMax);
OI_API	OI_ReadLimitAlarmsXY(int* XNeg, int* XPos, int* YNeg, int* YPos);
OI_API	OI_ClearUserLimitsXY();
OI_API	OI_WaitForStoppedXY();
OI_API	OI_GetSpeedXY( double* pdXSpeed, double* pdYSpeed );
OI_API	OI_SelectSpeedXY( double dXmmPerSec, double dYmmPerSec, int nFlags );
OI_API	OI_LookupSpeedXY( int nXCruise, int nYCruise, double* pdXSpeed, double* pdYSpeed );
OI_API	OI_GetFullTravelXY( double* pdXMin, double* pdXMax, double* pdYMin, double* pdYMax, BOOL* fInit );
OI_API	OI_DriveToLimitsXY( int nXLimitID, int nYLimitID, int nWait );
OI_API	OI_SetUserLimitsEnabledXY( BOOL bXMinEnabled, BOOL bXMaxEnabled, BOOL bYMinEnabled, BOOL bYMaxEnabled );
OI_API	OI_GetUserLimitsEnabledXY( LPBOOL pbXMinEnabled, LPBOOL pbXMaxEnabled, LPBOOL pbYMinEnabled, LPBOOL pbYMaxEnabled );
OI_API	OI_DefineUserLimitsXY(BOOL bXMinEnabled, double XMin, BOOL bXMaxEnabled,double XMax, BOOL bYMinEnabled,double YMin, BOOL bYMaxEnabled,double YMax);
OI_API	OI_SetUserLimitGuardDistanceXY( double dXDistanceMicrons, double dYDistanceMicrons );
OI_API	OI_GetUserLimitGuardDistanceXY( double* pdXDistanceMicrons, double* pdYDistanceMicrons );
OI_API	OI_MoveToXY_Abs( long lX, long lY, int nWait );
OI_API  OI_ReadXY_Abs(long* plX, long* plY);
OI_API  OI_GetBacklashXY(double* pdX, double* pdY);
OI_API	OI_InitByDialogXY(void);

OI_API	OI_SetAxisSwapXY( BOOL bSwapped );
OI_API	OI_GetAxisSwapXY( LPBOOL pbSwapped );

OI_API	OI_SetInitializeSpeedXY(double dMMperSecX, double dMMperSecY);
OI_API	OI_GetInitializeSpeedXY(double *pdMMperSecX, double *pdMMperSecY);
OI_API	OI_DriveAtSpeedXY(double dMicronsPerSecX, double dMicronsPerSecY);

///////////////////////////////////////////////////////////////////////
// Z Axis
OI_API OI_InitializeZ(double ZRangeAbove, double ZRangeBelow);
OI_API	OI_SetPositionZ(double ZPos);
OI_API  OI_ReadZ(double *pZ);
OI_API  OI_MoveToZ(double Z, int nWait);
OI_API	OI_StepZ(double ZDistance, int nWait);
OI_API  OI_ReadStatusZ(LPWORD lpwStatus);
OI_API	OI_SetRampZ(int nZRamp);
OI_API	OI_GetRampZ(int* pnZRamp);
OI_API	OI_SetCruiseZ(int nZCruise);
OI_API	OI_GetCruiseZ(int* pnZCruise);
OI_API	OI_SetDriveSenseZ(int nZDir);
OI_API	OI_GetDriveSenseZ(int* pnZDir);
OI_API	OI_DriveContinuousZ(int nSpeed);
OI_API	OI_HaltZ();
OI_API	OI_ReadRangeZ(double* pZMin, double* pZMax);
OI_API	OI_SetUserLimitsZ(double dZMin, double dZMax);
OI_API	OI_GetUserLimitsZ(double* pdZMin, double* pdZMax);
OI_API	OI_SetFocusJoystick(int nLeft, int nRight);
OI_API	OI_SetOriginZ();
OI_API	OI_ReadLimitAlarmsZ(int* ZNeg, int* ZPos);
OI_API	OI_SetPitchZ(double dZPitch);
OI_API	OI_GetPitchZ(double* pdZPitch);
OI_API	OI_WaitForStoppedZ();
OI_API	OI_SetUserLimitsEnabledZ( BOOL bMinEnabled, BOOL bMaxEnabled );
OI_API	OI_GetUserLimitsEnabledZ( LPBOOL pbMinEnabled, LPBOOL pbMaxEnabled );
OI_API	OI_GetSpeedZ( double* pdSpeed );
OI_API	OI_SelectSpeedZ( double dZmmPerSec, int nFlags );
OI_API	OI_LookupSpeedZ( int nCruise, double* pdSpeed );
OI_API	OI_ClearUserLimitsZ();
OI_API	OI_DriveToLimitZ( int nZLimitID, int nWait );
OI_API	OI_InitializeZLimits();
OI_API  OI_ReadSyncZ(LPWORD pwFieldNum, double *pZ);
OI_API  OI_SetPortZ(LPCTSTR szPort);
OI_API  OI_GetPortZ(LPSTR szBuffer, int nBufferLen);
OI_API	OI_MoveToZ_Abs( long lZ, int nWait );
OI_API	OI_ReadZ_Abs( long* plZ );
OI_API  OI_GetBacklashZ(double* pdZ);
OI_API	OI_DriveAtSpeedZ(double dMicronsPerSec);

///////////////////////////////////////////////////////////////////////
// Piezo Z via Dac1 on BLUE-DAC
OI_API	OI_IsPiezoFitted( LPBOOL pbFitted );
OI_API	OI_SetPiezoZ( double Z );
OI_API	OI_ReadPiezoZ( double* pZ );
OI_API	OI_SetPiezoOrigin();
OI_API	OI_SetPiezoRange( double dRangeMicrons );
OI_API	OI_GetPiezoRange( double* pdRangeMicrons );
OI_API	OI_GetPiezoLimits( double* pdMin, double* pdMax );
OI_API	OI_SetPiezoOriginDac(int nOriginDacVal );
OI_API	OI_GetPeizoOriginDac(int* pnOriginDacVal );
OI_API	OI_SetPiezoVoltageRange( double dMinVolts, double dMaxVolts );
OI_API	OI_GetPiezoVoltageRange( double* pdMinVolts, double* pdMaxVolts );
OI_API	OI_InitPiezo( BOOL bFindLImits );
OI_API	OI_SetPiezoDirection( int iReversed );
OI_API	OI_GetPiezoDirection( int* piReversed );
OI_API	OI_SweepPiezo( WORD wTriggerMode, WORD wTriggerDelayMsec, double dStart, double dFinish, WORD wNumEvents );

OI_API	OI_SelectActiveFocusDevice( int nCoarseOrFine );
OI_API	OI_GetActiveFocusDevice( int* pnCoarseOrFine );

OI_API	OI_SetFocusReadMode( int nFocusReadMode );
OI_API	OI_GetFocusReadMode( int* pnFocusReadMode );

OI_API	OI_SetPiezoADCSettings( WORD wADCMin, WORD wADCMax, WORD wADCThresh );
OI_API	OI_GetPiezoADCSettings(LPWORD pwADCMin, LPWORD pwADCMax, LPWORD pwADCThresh);
OI_API	OI_SetPiezoDacChannel( int nChan );
OI_API	OI_GetPiezoDacChannel( int* pnChan );

OI_API	OI_SetDAC( WORD wLoadDac1, WORD wDac1Val, WORD wLoadDac2, WORD wDac2Val, WORD wLoadDac3, WORD wDac3Val, WORD wLoadDac4, WORD wDac4Val );
OI_API	OI_ReadDAC( LPWORD pwValuesArray );

OI_API	OI_SweepDAC( WORD wDacChannel, WORD wDacTriggerMode, WORD wDacTriggerDelayMsec, WORD wDacStartValue, WORD wDacFinishValue, WORD wDacEventCount );

OI_API	OI_SetDACSweep( WORD wSlices, WORD wDacChannel, int nDacIncDecValue, WORD wTriggerSignal, WORD wTriggerDelay, WORD wTimerValue );
OI_API	OI_GetDACSweep( LPWORD pwSweepEnabled, LPWORD pwSlices, LPWORD pwDacChannel, int* pnDacIncDecValue, LPWORD pwTriggerSignal, LPWORD pwTriggerDelay, LPWORD pwDelayCopy, LPWORD pwTimerValue );
OI_API	OI_StartDACSweep( BOOL bStart );

////////////////////////////////////////////////////////
// predictive focus
OI_API	OI_SetPredictiveZ( double *xvals, double *yvals, double *zvals );
OI_API	OI_GetPredictiveZ( double x, double y, double *zpred, int *status );
OI_API	OI_GetPredictiveFlag( LPBOOL pbFlag );
OI_API	OI_SetPredictiveFlag( BOOL bFlag );
OI_API	OI_GetPredictiveZPoints( double *xvals, double *yvals, double *zvals );

OI_API	OI_SetAutoPredictiveZ( BOOL bEnabled );
OI_API	OI_GetAutoPredictiveZ( LPBOOL pbEnabled, LPBOOL pbValid, double *pdZPred);
OI_API	OI_SetAutoPredictiveZParams(double dX1, double dY1, double dZ1,
				double dCoeffA, double dCoeffB, double dCoeffC );

OI_API	OI_GetAutoPredictiveZParams( LPBOOL pbEnabled, LPBOOL pbValid,
				double *pdX1, double *pdY1, double *pdZ1,
				double *pdCoeffA, double *pdCoeffB, double *pdCoeffC
				);
OI_API	OI_InvalidatePredictiveZ();
OI_API	OI_SetPredictiveZOffset( double dOffset );
OI_API	OI_GetPredictiveZOffset( double *pdOffset );

OI_API	OI_SetMultiPredictiveZ( int nMethod, int nPoints, double *xvals, double *yvals, double *zvals );
OI_API	OI_GetMultiPredictiveZ( int* pnMethod, int* pnPoints, double *xvals, double *yvals, double *zvals );
OI_API	OI_UpdatePredictiveZ(int nOption);
OI_API	OI_GetPredictiveZDomains( int* pnDomains, double* ax, double* ay, double* az, double* bx, double* by, double* bz, double* cx, double* cy, double* cz );
OI_API	OI_GetCoincDomain( double xpos, double ypos, int* pnDomainIndex );
OI_API	OI_GetCoincDomainEx( double xpos, double ypos, int* pnDomainIndex, int* pnVertices, int *pnStatus);
OI_API	OI_GetPredictiveZDomainCount( int* pnDomains );

OI_API	OI_GetPredictiveZMethodCount( int* pnCount );
OI_API	OI_GetPredictiveZMethodInfo( int iZeroBasedIndex, int* piMethodID, char* szName, int iNameBufferSize );

OI_API	OI_SetPredictiveZLineTolerance( double dTolerance );
OI_API	OI_GetPredictiveZLineTolerance( double* pdTolerance );

OI_API	OI_GetFocusMapStatus(int* iActive, int* iTotalPoints, int* iValidPoints, int* iCurrentTriangleIndex, double* dPredZ );
OI_API	OI_GetPredictiveTrackingBufferStatus(int *pnStatus);

OI_API	OI_GetFocusMapDefaultTriangle( 
									  double* ax, double *ay, double *az, 
									  double *bx, double *by, double *bz, 
									  double *cx, double *cy, double *cz
									  );

OI_API	OI_SetPredictiveZSmallTriangleTolerance( double dTolerance );
OI_API	OI_GetPredictiveZSmallTriangleTolerance( double* pdTolerance );


///////////////////////////////////////////////////////////////////////
// Mousewheel Focus control
OI_API	OI_SetMouseWheelZ(BOOL bEnabled);
OI_API	OI_GetMouseWheelZ(BOOL *pbEnabled);
OI_API	OI_SetMouseWheelPars(double dStepSize, int nSpeed);
OI_API	OI_GetMouseWheelPars(double *pdStepSize, int *pnSpeed);
OI_API  OI_RockZ(BOOL bOn, double dZRange, int nSpeed);
OI_API  OI_OpenMouseWheelForFocus(HINSTANCE hinstModule,DWORD dwThreadId);
OI_API  OI_CloseMouseWheelForFocus();

///////////////////////////////////////////////////////////////////////
// F Axis
OI_API  OI_InitializeF();
OI_API  OI_InitializeFRange(double FNegLimit, double FPosLimit);
OI_API	OI_SetPositionF(double dFPos);
OI_API  OI_ReadF(double *pF);
OI_API  OI_MoveToF(double F, int nWait);
OI_API	OI_StepF(double FDistance, int nWait);
OI_API  OI_ReadStatusF(LPWORD lpwStatus);
OI_API	OI_SetRampF(int nFRamp);
OI_API	OI_GetRampF(int* pnFRamp);
OI_API	OI_SetCruiseF(int nFCruise);
OI_API	OI_GetCruiseF(int* pnFCruise);
OI_API	OI_SetDriveSenseF(int nFDir);
OI_API	OI_GetDriveSenseF(int* pnFDir);
OI_API	OI_HaltF();
OI_API	OI_ReadRangeF(double* pFMin, double* pFMax);
OI_API	OI_GetStepSizeF(double *dStepSize);
OI_API	OI_SetStepSizeF(double dStepSize);
OI_API	OI_WaitForStoppedF();
OI_API	OI_SetUserLimitsF(double dFMin, double dFMax);
OI_API	OI_GetUserLimitsF(double* pdFMin, double* pdFMax);
OI_API	OI_SetOriginF();
OI_API	OI_ReadLimitAlarmsF(int* FNeg, int* FPos);
OI_API	OI_SetPitchF(double dFPitch);
OI_API	OI_GetPitchF(double* pdFPitch);
OI_API	OI_ReadMaxMoveF(LPDWORD lpdwSteps, LPWORD lpwDecel );
OI_API	OI_GetSpeedF( double* pdSpeed);
OI_API	OI_SelectSpeedF( double dFmmPerSec, int nFlags );
OI_API	OI_LookupSpeedF( int nCruise, double* pdSpeed );
OI_API	OI_ClearUserLimitsF();
OI_API	OI_DriveToLimitF( int nLimitID, int nWait );
OI_API	OI_GetUserLimitsEnabledF( LPBOOL pbMinEnabled, LPBOOL pbMaxEnabled );
OI_API	OI_DriveContinuousF(int nSpeed);

///////////////////////////////////////////////////////////////////////
// T Axis
OI_API  OI_InitializeT();
OI_API  OI_InitializeTRange(double dNegLimit, double dPosLimit);
OI_API	OI_SetPositionT(double dPos);
OI_API  OI_ReadT(double *pdPos);
OI_API  OI_MoveToT(double dPos, int nWait);
OI_API	OI_StepT(double dDistance, int nWait);
OI_API  OI_ReadStatusT(LPWORD lpwStatus);
OI_API	OI_SetRampT(int nRamp);
OI_API	OI_GetRampT(int* pnRamp);
OI_API	OI_SetCruiseT(int nCruise);
OI_API	OI_GetCruiseT(int* pnCruise);
OI_API	OI_SetDriveSenseT(int nDir);
OI_API	OI_GetDriveSenseT(int* pnDir);
OI_API	OI_HaltT();
OI_API	OI_ReadRangeT(double* pdMin, double* pdMax);
OI_API	OI_GetStepSizeT(double *dStepSize);
OI_API	OI_SetStepSizeT(double dStepSize);
OI_API	OI_WaitForStoppedT();
OI_API	OI_SetUserLimitsT(double dMin, double dMax);
OI_API	OI_GetUserLimitsT(double* pdMin, double* pdMax);
OI_API	OI_SetOriginT();
OI_API	OI_ReadLimitAlarmsT(int* pdNeg, int* pdPos);
OI_API	OI_SetPitchT(double dPitchMM);
OI_API	OI_GetPitchT(double* pdPitchMM);
OI_API	OI_ReadMaxMoveT(LPDWORD lpdwSteps, LPWORD lpwDecel );
OI_API	OI_GetSpeedT( double* pdSpeed);
OI_API	OI_SelectSpeedT( double dFmmPerSec, int nFlags );
OI_API	OI_LookupSpeedT( int nCruise, double* pdSpeed );
OI_API	OI_ClearUserLimitsT();
OI_API	OI_DriveContinuousT(int nSpeed);

///////////////////////////////////////////////////////////////////////
// S Axis
OI_API  OI_InitializeS();
OI_API  OI_InitializeSRange(double dNegLimit, double dPosLimit);
OI_API	OI_SetPositionS(double dPos);
OI_API  OI_ReadS(double *pdPos);
OI_API  OI_MoveToS(double dPos, int nWait);
OI_API	OI_StepS(double dDistance, int nWait);
OI_API  OI_ReadStatusS(LPWORD lpwStatus);
OI_API	OI_SetRampS(int nRamp);
OI_API	OI_GetRampS(int* pnRamp);
OI_API	OI_SetCruiseS(int nCruise);
OI_API	OI_GetCruiseS(int* pnCruise);
OI_API	OI_SetDriveSenseS(int nDir);
OI_API	OI_GetDriveSenseS(int* pnDir);
OI_API	OI_HaltS();
OI_API	OI_ReadRangeS(double* pdMin, double* pdMax);
OI_API	OI_GetStepSizeS(double *dStepSize);
OI_API	OI_SetStepSizeS(double dStepSize);
OI_API	OI_WaitForStoppedS();
OI_API	OI_SetUserLimitsS(double dMin, double dMax);
OI_API	OI_GetUserLimitsS(double* pdMin, double* pdMax);
OI_API	OI_SetOriginS();
OI_API	OI_ReadLimitAlarmsS(int* pdNeg, int* pdPos);
OI_API	OI_SetPitchS(double dPitchMM);
OI_API	OI_GetPitchS(double* pdPitchMM);
OI_API	OI_ReadMaxMoveS(LPDWORD lpdwSteps, LPWORD lpwDecel );
OI_API	OI_GetSpeedS( double* pdSpeed);
OI_API	OI_SelectSpeedS( double dFmmPerSec, int nFlags );
OI_API	OI_LookupSpeedS( int nCruise, double* pdSpeed );
OI_API	OI_ClearUserLimitsS();

////////////////////////////////////////////////////////
// Filter wheel
OI_API	OI_SetFilterCount( int nFilters );
OI_API	OI_GetFilterCount( int *pnFilters );
OI_API	OI_DeleteFilter( int nPosition );
OI_API	OI_MoveToFilter( int nPosition, int nWait );
OI_API	OI_GetFilterPosition( int *pnPosition );
OI_API	OI_InitFilterChanger( int nMethod, double dUnitsPerRev );
OI_API	OI_SetFilterHomeOffset( double dOffset );
OI_API	OI_GetFilterHomeOffset( double *pdOffset );
OI_API	OI_WaitForStoppedFilter();
OI_API	OI_SetFilterName( int nPosition, LPSTR szBuffer );
OI_API	OI_GetFilterName( int nPosition, LPSTR szBuffer, int nBufferLen );
OI_API	OI_SetFilterDescription( int nPosition, LPSTR szBuffer );
OI_API	OI_GetFilterDescription( int nPosition, LPSTR szBuffer, int nBufferLen );
OI_API	OI_ReadFilterHomeInfo( LPBOOL lpbHomeFound, double *pdHomeLeft, double *pdHomeRight );
OI_API	OI_ReadFilterChangerInfo( double *pdUnitsPerRev, double *pdFilterSpacing );
OI_API	OI_SetFilterOffset( int nPosition, double dOffset );
OI_API	OI_GetFilterOffset( int nPosition, double *pdOffset );
OI_API	OI_SetFilterLocation( int nPosition );
OI_API	OI_ClearFilterHomeInfo( void );

OI_API	OI_SelectFilterChanger( int nChanger );
OI_API	OI_GetFilterChanger( int* pnChanger );
OI_API	OI_GetFilterChangerCount( int* pnChangers );
OI_API	OI_GetFilterChangerInfo( int nChanger, int* pnCard, int* pnAxisID );
OI_API	OI_SetFilterChangerInfo( int nChanger, int nCard, int nAxisID );
OI_API	OI_IsFilterChangerDetected( int nChanger, LPBOOL pbDetected );
OI_API	OI_SetFilterChangerConfig( int nChanger, int nControl );
OI_API	OI_GetFilterChangerConfig( int nChanger, int* pnControl );

OI_API	OI_SetFilterChangerCruise( int nChanger, int nCruise );
OI_API	OI_GetFilterChangerCruise( int nChanger, int* pnCruise );
OI_API	OI_SetFilterChangerRamp( int nChanger, int nRamp );
OI_API	OI_GetFilterChangerRamp( int nChanger, int* pnRamp );
OI_API	OI_GetFilterStatus( int nChanger, LPWORD pwStatus );

OI_API	OI_SetFilterChangerType( int nChanger, int nType );
OI_API	OI_GetFilterChangerType( int nChanger, int* pnType );
OI_API	OI_GetFilterChangerTypeCount( int nChanger, int* pnTypeCount );
OI_API	OI_GetFilterChangerTypeInfo( int nChanger, int nType, char* szName, int nNameBuffLength );

OI_API	OI_SetFilterChangerName( int nChanger, LPSTR szBuffer );
OI_API	OI_GetFilterChangerName( int nChanger, LPSTR szBuffer, int nBufferLen );

OI_API	OI_SetFilterCountEx(  int nChanger, int nFilters );
OI_API	OI_GetFilterCountEx(  int nChanger,int *pnFilters );
OI_API	OI_MoveToFilterEx(  int nChanger, int nPosition, int nWait );
OI_API	OI_GetFilterPositionEx(  int nChanger, int *pnPosition );
OI_API	OI_InitFilterChangerEx(  int nChanger, int nMethod, double dUnitsPerRev );
	
OI_API	OI_SetFilterAutoInitSpeedEnabled( BOOL bEnabled );
OI_API	OI_GetFilterAutoInitSpeedEnabled( BOOL *pbEnabled );

OI_API	OI_SetShutter( int nPosition, int nShutter );
OI_API	OI_GetShutter( int *pnPosition, int nShutter );
OI_API	OI_SetShutterMulti( int nStates, int nStateMask );
OI_API	OI_GetShutterMulti( int *pnStates );
OI_API	OI_SetShutterEx( LPBOOL lpbShutters, LPWORD lpwValues );
OI_API	OI_GetShutterEx( LPWORD pwRegister, LPSHUTTERINFO lpsiShutters, int* pnShutterCount );
OI_API	OI_SetShutterPolarity( int nShutter, int nReversed );
OI_API	OI_GetShutterPolarity( int nShutter, int *pnReversed );
OI_API	OI_IsShutterMoving(int nShutter, LPBOOL pbMoving );
OI_API	OI_WaitForShutter( int nShutter );
OI_API	OI_GetAvailableShutterCount( int *pnTotalSupported );

// Stepper-based shutters
OI_API	OI_SetShutterPosition( int nShutter, double dPercentOpen );
OI_API	OI_GetShutterPosition( int nShutter, double dPercentOpen );
OI_API	OI_SetShutterOpenPercent( int nShutter, double dPercentOpen );
OI_API	OI_GetShutterOpenPercent( int nShutter, double* pdPercentOpen );
OI_API	OI_InitShutter( int nShutter );
OI_API	OI_SetShutterAxis( int nShutter, int nAxisID );

///////////////////////////////////////////////////////////////////////
// Changer
OI_API	OI_GetContrastModeCount( int* pnModes );
OI_API	OI_GetContrastMode( int* pnMode );
OI_API	OI_SetContrastMode( int nMode, int nWait );
OI_API	OI_GetContrastModeName( int nMode, char* szName, int nLen );

OI_API	OI_ChangerGetCount( int* pnChangers );
OI_API	OI_ChangerSetController( int nChanger, int nController );
OI_API	OI_ChangerConfigure( int nChanger, int nController, int nComponent, int nOption );
OI_API	OI_ChangerGetConfiguration( int nChanger, int* pnController, int* pnComponent, int* pnOption );
OI_API	OI_ChangerGetName( int nChanger, char* szBuff, int nBuffLen );
OI_API	OI_ChangerSetName( int nChanger, char* szBuff );
OI_API	OI_ChangerIsConfigured( int nChanger, LPBOOL pbIsConfigured );
OI_API	OI_ChangerGetType( int nChanger, int* pnType );

OI_API	OI_ChangerGetComponentCount( int nChanger, int* pnSubComponentCount );
OI_API	OI_ChangerGetComponentName( int nChanger, int nComponent, char* szBuff, int nBuffLen );
OI_API	OI_ChangerSelectComponent( int nChanger, int nComponent );
OI_API	OI_ChangerGetSelectedComponent( int nChanger, int* pnComponent );
OI_API	OI_ChangerIsComponentAvailable( int nChanger, int nComponent, int* pnStatus );

OI_API	OI_ChangerGetPositionName( int nChanger, int nPos, char* szBuff, int nBuffLen );
OI_API	OI_ChangerGetPositionCount( int nChanger, int* pnCount );
OI_API	OI_ChangerGetPositionRange( int nChanger, int* pnMin, int* pnMax );
OI_API	OI_ChangerMoveTo( int nChanger, int nPos, int nWait );
OI_API	OI_ChangerReadPosition( int nChanger, int* pnPos );
OI_API	OI_ChangerIsMoving( int nChanger, LPBOOL pbMoving);
OI_API	OI_ChangerInit( int nChanger );
OI_API	OI_ChangerOpen( int nChanger );

///////////////////////////////////////////////////////////////////////
// Autofocus
OI_API	OI_SetAutoFocus( double dRange, int wSpeed, int wTolerance );
OI_API	OI_GetAutoFocus( double* pdRange, int* pnSpeed, int* pnTolerance );
OI_API	OI_AutoFocus();
OI_API	OI_AutoFocusEx( double dRange, int nSpeed, int nTolerance );
OI_API	OI_AutoFocus_Step( double dRange, int nSpeed, int nTolerance, double dStepSize );
OI_API	OI_AutoFocus_Fine( double dRange, int nSamples, double dStepSize );
OI_API  OI_SetAutoFocusThreshold(WORD wThresh);
OI_API  OI_GetAutoFocusThreshold(LPWORD lpwThresh);
OI_API  OI_ReadFocusScore(double* pdScore);
OI_API	OI_ReadFocusScoreEx( double* pdScore, double* pdZPos );
OI_API	OI_ReadFocusProfile(double* pdArray, double* pdZPos, int nSize, int* pnSamples);
OI_API	OI_RequestAutoFocusStatus( LPWORD pwFinished, LPWORD pwSuccess, LPWORD pwNumSamples );
OI_API	OI_RequestFocusStatus( LPWORD pwStatus );
OI_API	OI_WaitForAutoFocus();
OI_API	OI_SetAutoFocusMode(int nMode);
OI_API	OI_GetAutoFocusMode(int *pnMode);
OI_API	OI_SetAutoFocusMethod(int nMethod);
OI_API	OI_GetAutoFocusMethod(int *pnMethod);
OI_API	OI_SetAutoFocusEx( double dRange, int nSpeed, int nTolerance, double dStepSize );
OI_API	OI_GetAutoFocusEx( double* pdRange, int* pnSpeed, int* pnTolerance, double *pdStepSize );
OI_API	OI_SetFineFocusSamples( int nSamples );
OI_API	OI_GetFineFocusSamples( int* pnSamples );

OI_API	OI_SetContinuousAF( BOOL bOn );
OI_API	OI_GetContinuousAF( LPBOOL pbOn );
OI_API	OI_ComputeFocusScore( HANDLE hDib, double* pdScore );
OI_API  OI_ReadSyncCounter(LPWORD pwFieldNum);

OI_API	OI_SetAutoFocusHook( AUTOFOCUSPROC lpfnFocus, void* lpData );
OI_API	OI_SetFocusScoreHook( FOCUSSCOREPROC lpfnScore, void* lpData );
OI_API	OI_SetFocusStatusHook( FOCUSSTATUSPROC lpfnStatus, void* lpData );
OI_API	OI_SetFocusProfileHook( FOCUSPROFILEPROC lpfnProfile, void* lpData );

///////////////////////////////////////////////////////////////////////
// Video
OI_API  OI_SetVideoSettings(int nEvenPhase, int nEvenThreshold, int nOddPhase, int nOddThreshold);
OI_API  OI_GetVideoSettings(int* pnEvenPhase, int* pnEvenThreshold, int* pnOddPhase, int* pnOddThreshold);
OI_API  OI_ReadVideoData(LPWORD nStatus, LPDWORD pdwArea, LPWORD pwMaxChord, LPWORD pwMaxGradient);
OI_API	OI_ReadVideoResults( int nMode, LPDWORD pdwArea, LPWORD pwMaxChord);
OI_API	OI_ReadVideoResultsEx( int nMode, LPDWORD pdwArea, LPWORD pwMaxChord, LPWORD pwMaxGradient);
OI_API	OI_ReadVideoResultsXYZF( int nMode, double* pdResults, double* pdPositions );
OI_API	OI_ReadVideoResultsZ( int nMode, double* pdResults, double* pdZPos );
OI_API	OI_ReadVideoResultsXY( int nMode, double* pdResults, double* pdXPos, double* pdYPos );
OI_API	OI_IsVideoDetected(BOOL* bFound );
OI_API	OI_SetVideoWindow( int nXStart, int nXStop, int nYStart, int nYStop );
OI_API	OI_GetVideoWindow( int* pnXStart, int* pnXStop, int* pnYStart, int* pnYStop );
OI_API  OI_SetCameraSyncMode(WORD wMode, WORD wField );
OI_API  OI_GetCameraSyncMode(LPWORD pwMode, LPWORD pwField );
OI_API  OI_SetDC1Registers( LPWORD pwRegs );
OI_API  OI_GetDC1Registers( LPWORD pwRegs );

OI_API	OI_SetDigitalAutofocus( BOOL bEnable, WORD wIntervalMillSec, short nPulseMillSec );
OI_API	OI_GetDigitalAutofocus( BOOL* pbEnable, LPWORD pwIntervalMillSec, short* pnPulseMillSec );

///////////////////////////////////////////////////////////////////////
// General stops
OI_API  OI_HaltAllAxes(void);
OI_API  OI_EmergencyStopAll(void);
OI_API	OI_SetDefaultAbortKeys(BOOL bEnabled );
OI_API	OI_GetDefaultAbortKeys(LPBOOL pbEnabled );

///////////////////////////////////////////////////////////////////////
// Timeouts
OI_API	OI_SetVideoTimeout(DWORD dwMSecs);
OI_API	OI_GetVideoTimeout(LPDWORD lpdwMSecs);
OI_API	OI_SetAutoFocusTimeout(DWORD dwMSecs);
OI_API	OI_GetAutoFocusTimeout(LPDWORD lpdwMSecs);
OI_API	OI_SetMoveTimeout(DWORD dwMSecs);
OI_API	OI_GetMoveTimeout(LPDWORD lpdwMSecs);
OI_API	OI_SetFilterTimeout(DWORD dwMSecs);
OI_API	OI_GetFilterTimeout(LPDWORD lpdwMSecs);

///////////////////////////////////////////////////////////////////////
// Joystick
OI_API  OI_SetJoystickEnabled(BOOL bXEnabled,BOOL bYEnabled,BOOL bZEnabled);
OI_API  OI_GetJoystickEnabled(BOOL* bXEnabled,BOOL* bYEnabled,BOOL* bZEnabled);
OI_API	OI_SetJoystickSense( int nXSense, int nYSense, int nZSense );
OI_API	OI_GetJoystickSense( int* pnXSense, int* pnYSense, int* pnZSense );

OI_API	OI_ReadTrackballStatus( LPWORD pwStatus );
OI_API	OI_ClearTrackballStatus( WORD wMask );
OI_API	OI_SetTrackballControl( WORD wEnable );
OI_API	OI_GetTrackballControl( LPWORD pwEnable );
OI_API	OI_SetTrackballEnabled( BOOL bEnable );
OI_API	OI_GetTrackballEnabled( BOOL* pbEnable );

OI_API	OI_SetJoystickSettings( WORD wZDeviceSelect, LPWORD pwJoySensitivities, LPWORD wDigiSensitivities, WORD wMicPassThrough, LPWORD pwJoyButtons, LPWORD pwSmartMoveButtons );
OI_API	OI_GetJoystickSettings( LPWORD pwZDeviceSelect, LPWORD pwJoySensitivities, LPWORD wDigiSensitivities, LPWORD pwMicPassThrough, LPWORD pwJoyButtons, LPWORD pwSmartMoveButtons );

///////////////////////////////////////////////////////////////////////
// Conversion
OI_API	OI_MicronsToAbsoluteX(double dMicronVal, LPDWORD lpdwSteps);
OI_API	OI_MicronsToAbsoluteY(double dMicronVal, LPDWORD lpdwSteps);
OI_API	OI_MicronsToAbsoluteZ(double dMicronVal, LPDWORD lpdwSteps);
OI_API	OI_MicronsToAbsoluteF(double dMicronVal, LPDWORD lpdwSteps);

OI_API	OI_MicronsToStepsX(double dMicronVal, long* lpdwSteps);
OI_API	OI_MicronsToStepsY(double dMicronVal, long* lpdwSteps);
OI_API	OI_MicronsToStepsZ(double dMicronVal, long* lpdwSteps);
OI_API	OI_MicronsToStepsF(double dMicronVal, long* lpdwSteps);

OI_API	OI_AbsoluteToMicronsX(DWORD dwSteps, double* pdMicrons);
OI_API	OI_AbsoluteToMicronsY(DWORD dwSteps, double* pdMicrons);
OI_API	OI_AbsoluteToMicronsZ(DWORD dwSteps, double* pdMicrons);
OI_API	OI_AbsoluteToMicronsF(DWORD dwSteps, double* pdMicrons);

OI_API	OI_StepsToMicronsX(long dwSteps, double* pdMicrons);
OI_API	OI_StepsToMicronsY(long dwSteps, double* pdMicrons);
OI_API	OI_StepsToMicronsZ(long dwSteps, double* pdMicrons);
OI_API	OI_StepsToMicronsF(long dwSteps, double* pdMicrons);

OI_API	OI_ReadCounters( LPDWORD lpdwX, LPDWORD lpdwY, LPDWORD lpdwZ, LPDWORD lpdwF );
OI_API	OI_ReadCountersEx( LPDWORD lpdwDSP, LPDWORD lpdwEncoders );
OI_API	OI_SetCountersEx( LPDWORD lpdwDSP, LPDWORD lpdwEncoders );

///////////////////////////////////////////////////////////////////////
// File I/O
OI_API	OI_SaveSettings(LPCTSTR sFile);
OI_API	OI_LoadSettings(LPCTSTR sFile);
OI_API	OI_SavePositions(LPCTSTR sFile);
OI_API	OI_LoadPositions(LPCTSTR sFile);

OI_API	OI_SaveSettingsEx(LPCTSTR sFile, int nComponent );
OI_API	OI_LoadSettingsEx(LPCTSTR sFile, int nComponent );
OI_API	OI_SetAutoSaveEnabled(BOOL bEnabled);
OI_API	OI_GetAutoSaveEnabled(LPBOOL pbEnabled);
OI_API	OI_SetAutoSavePositionsEnabled(BOOL bEnabled);
OI_API	OI_GetAutoSavePositionsEnabled(LPBOOL pbEnabled);

OI_API	OI_GetDefaultSettingsFilename( char* szFile, int nBuffLen);

///////////////////////////////////////////////////////////////////////
// Error
OI_API	OI_GetLastError( int* pnCmd, int* pnRetCode, char* szDesc, int nLen );
OI_API	OI_GetControllerCommandStatus( LPWORD pwCommandStatus, LPWORD pwCommandID, LPWORD pwCommandStatusLastError, LPWORD pwLastErrorCommandID );

OI_API	OI_EnableMsgReportDlg( BOOL bEnabled );
OI_API	OI_ShowMessageDlg();
OI_API	OI_SetMessageDlgText( LPCTSTR szMsg );
OI_API	OI_HideMessageDlg();
OI_API	OI_CloseMessageDlg();

OI_API	OI_EnableErrorLogging( BOOL bEnable, int nLevel, char* szFilename );
OI_API	OI_WriteToErrorLog( char* szText );

OI_API	OI_ShowLogWindow();
OI_API	OI_HideLogWindow();
OI_API	OI_CloseLogWindow();
OI_API	OI_IsLogWindowVisible( BOOL *pbVisible );
OI_API	OI_GetLogWindowHandle( HANDLE *phWnd );
OI_API	OI_AddLogText( LPSTR szLog, int iLevel );
OI_API	OI_ClearLogList();
OI_API	OI_SetShowLogWindowOnStartup( BOOL bShow );
OI_API	OI_GetShowLogWindowOnStartup( BOOL *pbShow );
OI_API	OI_EnableLogging( BOOL bEnabled );
OI_API	OI_IsLoggingEnabled( LPBOOL pbEnabled );
OI_API	OI_SetLoggingLevel( int iLevel );
OI_API	OI_GetLoggingLevel( int* iLevel );

OI_API	OI_SetCommsEventHook( COMMSEVENTPROC lpfnEventHook, void* lpData );
OI_API	OI_DoCommsTest(int iIterations, double* pdResults, char* szTestDataBuff, int iLenTestDataBuff);

///////////////////////////////////////////////////////////////////////
// I/O
OI_API	OI_WriteIO( BYTE byVal );
OI_API	OI_ReadIO( LPBYTE lpbyVal );
OI_API	OI_ReadIOEx( int nCard, LPWORD	lpwVal);
OI_API	OI_ReadInputPorts( LPBYTE lpbyVal );
OI_API	OI_ReadInputPortsEx( int nCard, LPWORD lpwVals );

OI_API	OI_SetDAC( WORD wLoadDac1, WORD wDac1Val, WORD wLoadDac2, WORD wDac2Val, WORD wLoadDac3, WORD wDac3Val, WORD wLoadDac4, WORD wDac4Val );
OI_API	OI_ReadDAC( LPWORD pwValuesArray );

OI_API	OI_SweepDAC( WORD wDacChannel, WORD wDacTriggerMode, WORD wDacTriggerDelayMsec, WORD wDacStartValue, WORD wDacFinishValue, WORD wDacEventCount );

OI_API	OI_SetDACSweep( WORD wSlices, WORD wDacChannel, int nDacIncDecValue, WORD wTriggerSignal, WORD wTriggerDelay, WORD wTimerValue );
OI_API	OI_GetDACSweep( LPWORD pwSweepEnabled, LPWORD pwSlices, LPWORD pwDacChannel, int* pnDacIncDecValue, LPWORD pwTriggerSignal, LPWORD pwTriggerDelay, LPWORD pwDelayCopy, LPWORD pwTimerValue );
OI_API	OI_StartDACSweep( BOOL bStart );

////////////////////////////////////////////////////////
// Turret
OI_API	OI_SelectLensByMag( double dLensMag, BOOL *pbFound );
OI_API	OI_HaltTurret( void );
OI_API	OI_GetLensCount( int* pnLenses );
OI_API	OI_GetLensPos( int* pnPos );
OI_API	OI_GetLensMicroStepPos( int nPos, int* pnPos );
OI_API	OI_MoveToLens( int nPos );
OI_API	OI_GetLensMag( int nPos, double* pdMag );
OI_API	OI_GetLensName( int nPos, char* szName, int nLen );
OI_API	OI_GetLensNA( int nPos, double* pdNA );
OI_API	OI_SetLensMag( int nPos, double dMag );
OI_API	OI_SetLensName( int nPos, char* szName );
OI_API	OI_SetLensNA( int nPos, double dNA );
OI_API	OI_SetLensCount( int nLenses );
OI_API	OI_InitTurret( 
  int nMethod, // type of init
  int nLenses, // how many lenses
  double dUnitsPerRev, // how many units per rev, user init?
  double dFirstLensOffset // the offset from the home or min limit to first lens
);

////////////////////////////////////////////////////////
// Zoom
OI_API	OI_SetZoom( double dZoom );
OI_API	OI_GetZoom( double* pdZoom );
OI_API	OI_GetZoomRange( double* pdMinZoom, double* pdMaxZoom );

////////////////////////////////////////////////////////
// Lamp
OI_API	OI_SetLamp( int nChan, double dPercent );
OI_API	OI_GetLamp( int nChan, double* pdPercent );
OI_API	OI_SetLampChannel( int nChan );
OI_API	OI_GetLampChannel( int* pnChan );
OI_API	OI_SetLampIntensity( double dPercent );
OI_API	OI_GetLampIntensity( double* pdPercent );
OI_API	OI_GetLampChannels( int* pnNumChannels );

////////////////////////////////////////////////////////
// Extras
OI_API	OI_SetTopLens( int nPos );
OI_API	OI_GetTopLens( int* pnPos );
OI_API	OI_SetAperture( int nAperture, double dPos );
OI_API	OI_GetAperture( int nAperture, double* pdPos );

OI_API	OI_SetUserData( LPVOID pData );
OI_API	OI_GetUserData( LPVOID* pData );

// Glide Stage Specific
OI_API	OI_SetGlidePIDParameters( PID_STRUCT pid );
OI_API	OI_GetGlidePIDParameters( PID_STRUCT* pid );
OI_API	OI_ReadGlideDiagnosticData( int* pnOffset, int* pnNumSets, GLIDE_DATA_POINT* pGlideData, int nDataBufferSize );
OI_API	OI_SetGlideDiagnosticAxis( int nAxis );

OI_API	OI_ReadGlideStageDimensions(double *pdMotor1Array, double *pdMotor2Array, double *pdMotor3Array );
OI_API	OI_ClearGlideInitInfo( int iClearM1, int iClearM2, int iClearM3 );
OI_API	OI_MeasureGlideDimensions( double* dRangeMicrons, double *dHomeOffset );
OI_API	OI_ReadGlideDimensions( double* dRangeMicrons, double *dHomeOffset );
OI_API	OI_ReadGlideInitMethod(int* pMethod);

#ifdef __cplusplus
}            /* extern C*/
#endif  /* __cplusplus */


#endif // _OASIS4I_H