///////////////////////////////////////////////////////////////////////
// OI_CONST.H : Constant declares for OASIS4I DLL
//
// Version 4.0
//
// Copyright (C) 2000-2012 Objective Imaging Ltd.
// All rights reserved.
//
///////////////////////////////////////////////////////////////////////

#ifndef _OI_CONST_H
#define _OI_CONST_H


// The OI_ exports always return int status codes
#ifdef OI_XYZ_EXPORTS
#define OI_API __declspec(dllexport) int WINAPI 
#else 
#define OI_API int WINAPI 
#endif

// for exported variables
#ifdef OI_XYZ_EXPORTS
#define OI_VAR __declspec(dllexport)  
#else
#define OI_VAR //__declspec(dllimport) 
#endif

// for other funcs
#ifndef OI_XYZ_FUNC
#define OI_XYZ_FUNC int
#endif

///////////////// OI DLL CONSTANTS /////////////////

///////////////////////////////////////////
// Return Codes
///////////////////////////////////////////
#define OI_OK				0
#define OI_FAILED			1
#define OI_ABORT			2
#define OI_NOHARDWARE		4
#define OI_TIMEOUT			8
#define OI_INVALIDARG		0x10		/* 16  */
#define OI_HARDWAREBUSY		0x20		/* 32 */
#define OI_ACCESSDENIED		0x40		/* 64 */
#define OI_NOTSUPPORTED		0x80		/* 128 */
#define	OI_ILLEGALAXIS		0x100		/* 256 */
#define OI_INVALIDCONFIG	0x200		/* 512 */
#define OI_MAXMOVEFAIL		0x400		/* 1024 */
#define OI_COMM_OUTFAIL		0x800		/* 2048 */
#define	OI_COMM_INFAIL		0x1000		/* 4096 */
#define OI_ACK_FAIL			0x2000		/* 8192 */
#define OI_ACK_TIMEOUT		0x4000
/* reserved					0x8000 */
#define OI_X_INVALID		0x10000
#define OI_Y_INVALID		0x20000
#define OI_Z_INVALID		0x40000
#define OI_F_INVALID		0x80000
#define OI_T_INVALID		0x100000
#define OI_S_INVALID		0x200000

///////////////////////////////////////////
// Return Code Test Macros
///////////////////////////////////////////
#define OIFAILED(x)		((x>0) ? TRUE : FALSE)
#define OISUCCESS(x)	((x==0) ? TRUE : FALSE)

///////////////////////////////////////////
// Axes IDs
///////////////////////////////////////////
#define OI_XAXIS 1
#define OI_YAXIS 2
#define OI_ZAXIS 3
#define OI_FAXIS 4
#define OI_TAXIS 5
#define OI_SAXIS 6

///////////////////////////////////////////
// DEVICE IDs
///////////////////////////////////////////
#define		OASIS_4I		0 // Serial numbers starting: 2000-...
#define		OASIS_BLUE		1 // Serial numbers starting: 2032-...
#define		OASIS_EXPRESS	2 // Serial numbers starting: 2054-...
#define		OASIS_USB		3
#define		OASIS_GLIDE		4
#define		OASIS_REMOTE	5

///////////////////////////////////////////
// DEVICE Types
///////////////////////////////////////////
#define		OI_TYPE_SIM			0
#define		OI_TYPE_PCI			1 
#define		OI_TYPE_USB			2 
#define		OI_TYPE_NETWORK		3 

///////////////////////////////////////////
// MULTI-BOARD INFO
///////////////////////////////////////////
#define	OI_MAX_AXES		20
#define MAX_BOARDS		4
#define MAX_AXES_PER	6

///////////////////////////////////////////
// AXIS ID HANDLING
///////////////////////////////////////////
#define OI_MULTI_MODE_ID		0 // use 1 to MAX_AXES_PER*N, N=number of boards
#define OI_MULTI_MODE_ROUTE		1 // use 1 to MAX_AXES_PER on each board

///////////////////////////////////////////
// Axis Types (reserved)
///////////////////////////////////////////
#define OI_TYPE_NOT_FITTED	0
#define OI_TYPE_STEPPER		1
#define OI_TYPE_DC			2
#define OI_TYPE_SIMULATED	3

///////////////////////////////////////////
// Init Methods (reserved)
///////////////////////////////////////////
#define OI_INITBY_MANUAL	0
#define OI_INITBY_SWITCH1	1
#define OI_INITBY_SWITCH2	2
#define OI_INITBY_DIALOG	4
#define OI_INITBY_HOME		8

#define OI_INIT_ORIGIN_MIN		0
#define OI_INIT_ORIGIN_CENTRAL	1

///////////////////////////////////////////
// Hardware Modes
///////////////////////////////////////////
#define OI_NOTFITTED		-1
#define OI_SIM				0
#define OI_OASIS			1
#define OI_REMOTE			2
#define OI_ONYX				3
#define OI_GLIDE			4
#define	OI_GLIDE_EXT		5
#define OI_LEICA_DM			10
#define OI_LEICA_DM2		11
#define OI_LEICA_MZ			12
#define OI_LEICA_AHM		13
#define OI_LEICA_ISOPRO		14	
#define OI_LEICA_ZOOM		15
#define OI_LEICA_ISOPRO_AHM	16
#define OI_OLYMPUS_BX		20
#define OI_OLYMPUS_IX		21
#define	OI_OLYMPUS_LASER_AF	22
#define OI_NAVITAR			50
#define OI_OPTEM			51
#define OI_NANOZ			60 // Mad City Labs Nano-Z drives
#define OI_ZEISS_MTB		70
#define OI_ZEISS_MTB_LAMPS	71
#define OI_ZEISS_MTB_APERTURE	72
#define OI_ZEISS_RS232		73
#define OI_ARCUS			80
#define OI_OASIS_DAC		100
#define	OI_BLUE_DAC1		OI_OASIS_DAC+1
#define	OI_BLUE_DAC2		OI_OASIS_DAC+2
#define	OI_BLUE_DAC3		OI_OASIS_DAC+3
#define	OI_BLUE_DAC4		OI_OASIS_DAC+4
#define OI_OASIS_FILTER		110
#define OI_PRIOR_PROSCAN	80
#define OI_PRIOR_LUMEN		81
#define OI_CRI_MICROCOLOR	90
#define OI_SCHOTT_LAMP		120
#define OI_NIKON_NI			200
#define OI_CONIX			300

///////////////////////////////////////////
// Status Codes
///////////////////////////////////////////
#define S_LIMIT_PHY_NEG		0x0001
#define S_LIMIT_USR_NEG		0x0002
#define S_LIMIT_PHY_POS		0x0008
#define S_LIMIT_USR_POS		0x0004
#define S_LIMIT_USR_NEG_SET 0x0010
#define S_LIMIT_USR_POS_SET 0x0020
#define S_INITIALIZED		0x0040
#define S_DIRECTION			0x0080
#define S_MOVING			0x0100
#define S_ENCODER_DIRECTION	0x0200
#define S_ENCODER_MOVING	0x0400
#define S_OVER_VELOCITY		0x2000
#define S_OVER_CURRENT		0x4000
#define S_MOTOR_DETECTED	0x8000

///////////////////////////////////////////
// PCB STATUS BITS
/*
bit meaning
----------------
31	Reserved
30	Reserved
29	Reserved
28	Reserved
27	Reserved
26	Reserved
25	Reserved
24	Reserved
23	Reserved
22	Reserved
21	Reserved
20	Reserved
19	Flash_user_OK		( 1 = Flash user area checksum OK ) (32)
18	Flash_OI_OK			( 1 = Flash OI area checksum OK ) (34)
17	Reserved
16	Joystick_detect		( 1 = Joystick unit fitted )
15	Reserved
14	Trackball_detect		( 1 = Serial device is Kensington Trackball 5)
13	Mouse_detect			( 1 = Serial device is standard 2-button mouse)
12	Serial_Device_detect		( 1 = Serial device detected on RS232_0)
11	Camera_type			( 1 = Colour, 0 = Mono )
10	Camera_frequency		( 1 = 50 Hz, 0 = 60 Hz )
9	Camera_channel		( 1 = Channel 3, 0 = channel 0 (default))
8	Camera_detect		( 1 = Camera input detected )
7	Video_Encoder_OK		( 1 = Encoder configured OK )
6	Autofocus_Module_type_1	( 2 bit code indicating module type )
5	Autofocus_Module_type_0	( 2 bit code indicating module type )
4	Autofocus_Module_fitted	( 1 = Module Detected )
3	ADC_Analogue_input_X	( 1 = ADC zero (correct) at switch on )
2	ADC_Analogue_input_Y	( 1 = ADC zero (correct) at switch on )
1	PCB_Temperature		( 1 = Temperature too high )
0	Motor_volts_OK		( 1 = Motor supply >= 10V i.e. OK )
*/
///////////////////////////////////////////
#define S_PCB_MOTOR_VOLTS_OK		0x1
#define S_PCB_TEMP_OK				0x2
#define S_PCB_ADC_YIN_OK			0x4
#define S_PCB_ADC_XIN_OK			0x8
#define S_PCB_AF_FITTED				0x10
#define S_PCB_AF_TYPE0				0x20
#define S_PCB_AF_TYPE1				0x40
#define S_PCB_VIDEO_ENCODER_OK		0x80
#define S_PCB_CAMERA_DETECTED		0x100
#define S_PCB_CAMERA_CHANNEL		0x200
#define S_PCB_CAMERA_FREQ			0x400
#define S_PCB_CAMERA_TYPE			0x800
#define S_PCB_SERIAL_DEV_DETECTED	0x1000
#define S_PCB_MOUSE_DETECTED		0x2000
#define S_PCB_TRACKBALL_FITTED		0x4000
//		reserved					0x8000
#define S_PCB_JOYSTICK_FITTED		0x10000
//		reserved					0x20000
#define S_PCB_FLASH_OI_OK			0x40000
#define S_PCB_FLASH_USER_OK			0x80000

#define S_PCBEX_XA1_FITTED			0x4
#define S_PCBEX_DC1_FITTED			0x1
#define S_PCBEX_EXPIO_FITTED		0x1
#define S_PCBEX_DAC_FITTED			0x3

///////////////////////////////////////////
// OASIS-4i Modules
///////////////////////////////////////////
#define OASIS_AF		1
#define OASIS_XA1		2
#define OASIS_DC1		3

///////////////////////////////////////////
// OASIS-blue Modules
///////////////////////////////////////////
#define BLUE_EXPIO		4
#define BLUE_DAC		5

///////////////////////////////////////////
// Range constants
///////////////////////////////////////////
#define OI_RAMP_SLOW	0
#define OI_RAMP_NORMAL	1
#define OI_RAMP_FAST	2
#define OI_RAMP_USER	3

///////////////////////////////////////////
// Range constants
///////////////////////////////////////////
#define OI_CRUISE_MIN		0
#define OI_CRUISE_MAX		511
#define OI_RAMP_MIN			0
#define	OI_RAMP_MAX			3
#define OI_DRIVE_SPEED_MIN	-4096
#define OI_DRIVE_SPEED_MAX	4096

////////////////////////////////////////////////////////
// Component configuration support
////////////////////////////////////////////////////////
#define	OI_CFG_STAGE		1

#define	OI_CFG_FOCUS		2
#define OI_CFG_COARSEFOCUS	OI_CFG_FOCUS
#define	OI_CFG_FINEFOCUS	3
#define OI_CFG_AUTOFOCUS	4
#define OI_CFG_SMARTFOCUS	5

#define	OI_CFG_FILTER		8
#define OI_CFG_FILTER1		OI_CFG_FILTER
#define OI_CFG_FILTER2		16
#define OI_CFG_FILTER3		OI_CFG_FILTER2+1
#define OI_CFG_FILTER4		OI_CFG_FILTER2+2
#define OI_CFG_FILTER5		OI_CFG_FILTER3+3
#define OI_CFG_FILTER6		OI_CFG_FILTER4+4
#define OI_CFG_FILTER7		OI_CFG_FILTER5+5
#define OI_CFG_FILTER8		OI_CFG_FILTER6+6

#define	OI_CFG_TURRET		32

#define OI_CFG_LAMP1		64
#define OI_CFG_LAMP2		128

#define OI_CFG_SHUTTER1		256
#define OI_CFG_SHUTTER2		OI_CFG_SHUTTER1+1
#define OI_CFG_SHUTTER3		OI_CFG_SHUTTER1+2
#define OI_CFG_SHUTTER4		OI_CFG_SHUTTER1+3

#define OI_CFG_CHANGER		0x1000

////////////////////////////////////////////////////////
// Microscope changer information
////////////////////////////////////////////////////////

#define OI_MAX_CHANGERS		64	

#define OI_CHANGER_TYPE_NONE	-1
#define OI_CHANGER_TYPE_FILTER	0
#define	OI_CHANGER_TYPE_SHUTTER	1
#define OI_CHANGER_TYPE_OBS		2
#define OI_CHANGER_TYPE_LAMP	3
#define OI_CHANGER_TYPE_USER	4
#define OI_CHANGER_TYPE_IO		5
#define OI_CHANGER_TYPE_ONOFF	6

typedef struct tagOI_CHANGER
{
	int nControllerID;
	int nType;
	int nCard;
	int nAxis;
	int nMinPosition;
	int nMaxPosition;
	char szName[80];
	int m_nIndex;
	int m_nOption;
	int m_nSubComponent;
	int m_nController;
} OICHANGER, *POICHANGER;

// OASIS Sub-Changers
#define OI_OASIS_FILTER1			0
#define OI_OASIS_FILTER2			1
#define OI_OASIS_FILTER3			2
#define OI_OASIS_FILTER4			3
#define OI_OASIS_FILTER5			4
#define OI_OASIS_FILTER6			5
#define OI_OASIS_FILTER7			6
#define OI_OASIS_FILTER8			7
#define OI_OASIS_SHUTTER1			8
#define OI_OASIS_SHUTTER2			9
#define OI_OASIS_SHUTTER3			10
#define OI_OASIS_SHUTTER4			11
#define OI_OASIS_LAMP1				12

#define OI_OASIS_IO1				13
#define OI_OASIS_IO2				14
#define OI_OASIS_IO3				15
#define OI_OASIS_IO4				16
#define OI_OASIS_IO5				17
#define OI_OASIS_IO6				18
#define OI_OASIS_IO7				19
#define OI_OASIS_IO8				20

#define OI_OASIS_COMP_COUNT			20

// LEICA AHM Sub-Changers
#define	OI_LEICA_AHM_IL				0
#define	OI_LEICA_AHM_FW				1
#define	OI_LEICA_AHM_DIC			2
#define	OI_LEICA_AHM_CONDENSOR		3
#define	OI_LEICA_AHM_CONTRAST		4
#define	OI_LEICA_AHM_ILSHUTTER		5
#define	OI_LEICA_AHM_TLSHUTTER		6
#define	OI_LEICA_AHM_ILTLSWITCH		7
#define	OI_LEICA_AHM_COMP_COUNT		8

// LEICA AHM Sub-Changers
#define	OI_LEICA_DM_IL				0
#define	OI_LEICA_DM_ILSHUTTER		1
#define	OI_LEICA_DM_TLLAMP			2
#define	OI_LEICA_DM_ILLAMP			3
#define OI_LEICA_DM_CONDENSOR		4
#define OI_LEICA_DM_CONTRAST		5
#define	OI_LEICA_DM_COMP_COUNT		6


#define OI_OLYMPUS_BX_MIRROR		0
#define OI_OLYMPUS_BX_CONDENSOR		1	
#define OI_OLYMPUS_BX_CONTRAST		2
#define OI_OLYMPUS_BX_FILTER1		3
#define OI_OLYMPUS_BX_FILTER2		4
#define OI_OLYMPUS_BX_FILTER3		5
#define OI_OLYMPUS_BX_SHUTTER1		6
#define OI_OLYMPUS_BX_SHUTTER2		7
#define OI_OLYMPUS_BX_SIDEPORT		8
#define OI_OLYMPUS_BX_BOTTOMPORT	9
#define	OI_OLYMPUS_BX_COMP_COUNT	10

#define OI_ZEISS_MTB_RLTLSWITCH			0
#define	OI_ZEISS_MTB_RLFILTER			1
#define OI_ZEISS_MTB_RLVIRTUALFILTER	2
#define OI_ZEISS_MTB_RLFILTER1			3
#define OI_ZEISS_MTB_RLFILTER2			4
#define OI_ZEISS_MTB_TLVIRTUALFILTER	5
#define OI_ZEISS_MTB_TLFILTER1			6
#define OI_ZEISS_MTB_TLFILTER2			7
#define OI_ZEISS_MTB_CONDENSERCONTRAST	8
#define	OI_ZEISS_MTB_RLSHUTTER			9
#define	OI_ZEISS_MTB_TLSHUTTER			10
#define	OI_ZEISS_MTB_COMP_COUNT			11

// SHCHOTT DCR IV Changers
#define OI_SCHOTT_LAMP_INTENS	0
#define	OI_SCHOTT_LAMP_ONOFF	1
#define	OI_SCHOTT_LAMP_EQUALIZER	2
#define OI_SCHOTT_LED_INTENS	3
#define	OI_SCHOTT_LED_ONOFF		4

////////////////////////////////////////////////////////
#define OI_MAX_FILTER	8
#define OI_MAX_LAMP		2
#define	OI_MAX_SHUTTER	4

typedef struct tagOICONFIGURATION
{
	int Stage;
	int Focus;
	int Filter[OI_MAX_FILTER];
	int Turret;
	int Lamp[OI_MAX_LAMP];
	int Autofocus;
	int Shutter[OI_MAX_SHUTTER];
	int FineFocus;
	int Changer[OI_MAX_CHANGERS];
} OICONFIGURATION;

#define MAX_CONTROLLERS		32

#define OI_MAX_DEVICES		8

#define OI_EXTOPT_NOLASIMAGE	1


////////////////////////////////////////////////////////
// Autofocus methods
////////////////////////////////////////////////////////
#define OI_AF_COARSE	0
#define OI_AF_FINE		1
#define	OI_AF_STEP		2
#define OI_DAF_COARSE	4
#define OI_DAF_FINE		8
#define OI_DAF_STEP		16

// Hook function for user-defined autofocus
typedef int (CALLBACK* AUTOFOCUSPROC)(void*);
typedef int (CALLBACK* FOCUSSCOREPROC)(void*, double*);
typedef int (CALLBACK* FOCUSSTATUSPROC)( void*, LPWORD /*pwFinished*/, LPWORD /*pwSuccess*/, LPWORD /*pwNumSamples*/ );
typedef int (CALLBACK* FOCUSPROFILEPROC)( void*, double* /*pdArray*/, double* /*pdZPos*/, int /*nSize*/, int* /*pnSamples*/ );


// Comms event hook
typedef int (CALLBACK* COMMSEVENTPROC)(int /*event type*/, int /*error code*/, char* /*description*/);

#define OI_COMM_EVENT_OUTFAIL	0
#define OI_COMM_EVENT_INFAIL	1
#define OI_COMM_EVENT_RESET		2

////////////////////////////////////////////////////////
// Predictive focus
////////////////////////////////////////////////////////
#define OI_PF_MULTI_PLANE			0
#define OI_PF_SINGLE_PLANE			1
#define OI_PF_LOCAL_MEAN			2
#define OI_PF_TRIANGULATE			3
#define OI_PF_TRIANGULATE_MEAN		4
#define OI_PF_X_INTERPOLATE			5
#define OI_PF_Y_INTERPOLATE			6
#define OI_PF_TRIANGULATE_EX1		11
#define OI_PF_TRIANGULATE_EX2		12
#define OI_PF_TRIANGULATE_EX3		13
#define OI_PF_TRIANGULATE_EX4		14

typedef struct tagFOCUSMAPPOINT
{
	int index;
	double dAx;
	double dAy;
	double dBx;
	double dBy;
	double dCx;
	double dCy;
	double dX0;
	double dY0;
	double dZ0;
	double dAC;
	double dBC;
} FOCUS_MAP_POINT;

typedef struct tagFOCUSMAPSTATUS
{
	int iActive;
	int iTotalPoints;
	int iValidPoints;
	int iCurrentTriangleIndex;
	double dPredZ;
} FOCUS_MAP_STATUS;

// For OI_GetPredictiveTrackingBufferStatus
#define OI_PF_BUFFER_STATUS_NOTSUPPORTED	0
#define OI_PF_BUFFER_STATUS_INVALID			1
#define OI_PF_BUFFER_STATUS_FOCUSMAP		2
#define OI_PF_BUFFER_STATUS_SYNCLIST		3

////////////////////////////////////////////////////////
// Piezo Focus
////////////////////////////////////////////////////////

// for OI_SetDAC Load parameters
#define	OI_PIEZO_DONT_SET				0
#define	OI_PIEZO_SET_ON_FRAME_IRQ		1
#define	OI_PIEZO_SET_NOW				2

// for focus read, is the value the currently active device
// or is it cumulative, e.g., Z = Zmotor + Zpiezo
// See OI_SelectActiveFocusDevice and OI_SetFocusReadMode
#define	OI_REPORT_Z_ACTIVE				0
#define OI_REPORT_Z_CUMUL				1

////////////////////////////////////////////////////////
// Filter initialization methods
////////////////////////////////////////////////////////
#define OI_FILTER_INIT_HOME			0
#define OI_FILTER_INIT_LIMITS		1
#define OI_FILTER_INIT_USER			2

////////////////////////////////////////////////////////
// Filter Wheel Makes
////////////////////////////////////////////////////////

#define OI_FILTER_OTHER				0
#define OI_FILTER_LUDL				1
#define OI_FILTER_PRIOR				2
#define OI_FILTER_SUTTER			3
#define OI_FILTER_LUMEN_WHEEL		4
#define OI_FILTER_LUMEN_SHUTTER		5
#define	OI_FILTER_LEICA				6
#define OI_FILTER_OLYMPUS			7

#define OI_FILTER_TYPE_COUNT		8

////////////////////////////////////////////////////////
// OI-SC4 Shutter Controller masks
////////////////////////////////////////////////////////
#define SHUTTER1	1
#define SHUTTER2	2
#define SHUTTER3	4
#define SHUTTER4	8

////////////////////////////////////////////////////////
// Trackball support
////////////////////////////////////////////////////////
#define OI_BUTTON1				1
#define OI_BUTTON2				2
#define OI_BUTTON3				4
#define OI_BUTTON4				8
#define OI_BUTTON1_PRESSED		1
#define OI_BUTTON1_RELEASED		2
#define OI_BUTTON2_PRESSED		4
#define OI_BUTTON2_RELEASED		8
#define OI_BUTTON3_PRESSED		16
#define OI_BUTTON3_RELEASED		32
#define OI_BUTTON4_PRESSED		64
#define OI_BUTTON4_RELEASED		128
#define OI_CLEAR_ALL_BUTTONS	0xffff

////////////////////////////////////////////////////////
// Shared Capabilities
////////////////////////////////////////////////////////

#define OI_CAP_DEVICE_UNLICENSED	0x10000000

// Use only with direct comm devices that 
// require port specification in the DLL
#define OI_CAP_DEVICE_RS232			0x20000000

////////////////////////////////////////////////////////
// Turret Capabilities
////////////////////////////////////////////////////////

#define OI_TURRET_CAP_AUTOMOVE   0x0001
#define OI_TURRET_CAP_ADDREMOVE  0x0002
#define OI_TURRET_CAP_PROMOTE    0x0004
#define OI_TURRET_CAP_TOPLENS    0x0008
#define OI_TURRET_CAP_LAMP		 0x0010
#define OI_TURRET_CAP_APERTURE   0x0020
#define OI_TURRET_CAP_ZOOM		 0x0040
#define OI_TURRET_CAP_ENCODED	 0x0080

////////////////////////////////////////////////////////
// Focus Capabilities
////////////////////////////////////////////////////////

#define OI_FOCUS_CAP_SOFTLIMIT		0x0001 
#define OI_FOCUS_CAP_HARDLIMIT		0x0002 
#define OI_FOCUS_CAP_FASTUPDATE		0x0004 
#define OI_FOCUS_CAP_PREDICTIVE		0x0008
#define OI_FOCUS_CAP_SERIAL			0x0010
#define OI_FOCUS_CAP_TRIGGER_IN		0x0020
#define OI_FOCUS_CAP_TRIGGER_OUT	0x0040
#define OI_FOCUS_CAP_PREDZMAP		0x0080
#define OI_FOCUS_CAP_PREDZSYNC		0x0100
#define OI_FOCUS_CAP_TURBO			0x0200

////////////////////////////////////////////////////////
// Controller Capabilities
////////////////////////////////////////////////////////
#define OI_CAP_RESET		0x1000
#define OI_CAP_TURBOSCAN	0x2000
#define OI_CAP_FASTUPDATE	0x4000


typedef struct tagSHUTTERINFO
{
	WORD wDurationHV; // High Voltage duration (20-100 mS)
	WORD wTimerHV; // High Voltage current timer value (20-100 mS)
	WORD wDurationLV; // Low (holding) Voltage duration (0 to 65535 mS)
	WORD wTimerLV; // Low (holding) Voltage current timer value (0 to 65535 mS)
} SHUTTERINFO, *LPSHUTTERINFO;

#define OI_SHUTTER_OPEN   65535
#define OI_SHUTTER_CLOSE	0


typedef int (CALLBACK* NOTIFYPROC)(void*);

////////////////////////////////////////////////////////
// Logging Levels
////////////////////////////////////////////////////////

#define OI_LOG_CMD				0x1
#define OI_LOG_DRIVER_CMD		0x2
#define OI_LOG_BASIC_READS		0x4
#define OI_LOG_POS_READS		0x8
#define OI_LOG_STATUS_READS		0x10
#define OI_LOG_POS_READS_DRV	0x20
#define OI_LOG_STATUS_READS_DRV	0x40
#define	OI_LOG_DRIVER			0x80
#define OI_LOG_PRED_Z			0x100
#define OI_LOG_PRED_Z_UPDATES	0x200
#define OI_LOG_ERROR			0x400
#define OI_LOG_COMMS			0x800
#define OI_LOG_DIAG				0x8000

#define OI_LOG_ALL				0xffff

/*
1) Motor select = (0 - 8) where 0 disables diagnostic data gathering, 1-8 selects which motor to gather data about.
2) Clock Frequency (Hz) - This is the frequency of the clock measuring the widths of encoder pulses.
3) Velocity Loop Frequency (Hz)
4) Position Loop Frequency (Hz)
5) Encoder resolution (nm)
6) Reserved
7) Kp = 0.000 - 1.000 , Velocity loop Proportional Constant
8) Ki = 0.000 - 1.000 , Velocity loop Integral Constant
9) Kd = 0.000 - 1.000 , Velocity loop Derivative Constant
10) KVff = 0.000 - 1.000 , Velocity loop Velocity Feed-Forward Constant
11) KAff = 0.000 - 1.000 , Velocity loop Acceleration Feed-Forward Constant
12) Kpp = 0.000 - 1.000 , Position loop Proportional Constant
13) Kip = 0.000 - 1.000 , Position loop Integral Constant
*/
typedef struct tagPID
{
	UINT MotorSelect;
	UINT ClockFreq;
	UINT VelocityLoopFreq;
	UINT PositionLoopFreq;
	UINT EncoderRes_nm;
	UINT reserved;
	float Kp;
	float Ki;
	float Kd;
	float KVff;
	float KAff;
	float Kpp;
	float Kip;
} PID_STRUCT, * LPPID_STRUCT;


typedef struct tabGLIDE_DATA
{
	int iEncoder;
	int iSpeedTarget_nm;
	int iSpeedMeasured_nm;
	unsigned int uDistanceCalc;
} GLIDE_DATA_POINT, *LPGLIDE_DATA_POINT;

////////////////////////////////////////////////////////
// License IDs
////////////////////////////////////////////////////////
#define	OI_LIC_ACTIVEX			0
#define	OI_LIC_SYNCRO			1
#define	OI_LIC_SURVEYOR			2
#define	OI_LIC_TURBOSCAN		3
#define	OI_LIC_OLYMPUS			4
#define	OI_LIC_DISCEXP			5
#define	OI_LIC_NAVIGATOR		6
#define	OI_LIC_ZSTACK			7
#define	OI_LIC_MARKFIND			8
#define	OI_LIC_SURVEYORLITE		9
#define	OI_LIC_SLIDEX			10
#define	OI_LIC_MULTICHAN		11
#define	OI_LIC_DETECTOR			12
#define	OI_LIC_SLIDELOADER		13
#define OI_LIC_WAFERSHUTTLE		14
#define OI_LIC_GLISSANDO		15
#define OI_LIC_ZSTACK_PLUS		16
#define OI_LIC_PREMIER			17
#define OI_LIC_MEDIACY			17
#define OI_LIC_EXTRA			100
#define OI_LIC_DEVICES			200

////////////////////////////////////////////////////////
// Glide Stage Sub-types
////////////////////////////////////////////////////////
#define OI_GLIDE_MK1			0
#define OI_GLIDE_MK2			1
#define OI_GLIDE_MK3			2

////////////////////////////////////////////////////////
// Settings File Formats
////////////////////////////////////////////////////////
#define OI_SETTINGS_FORMAT_XML	0
#define OI_SETTINGS_FORMAT_INI	1

////////////////////////////////////////////////////////
// Glide Flash Serial Number types
////////////////////////////////////////////////////////
#define OI_GLIDE_SERIAL_BOARD	0
#define OI_GLIDE_SERIAL_STAGE	1
#define OI_GLIDE_SERIAL_SYSTEM	2


typedef enum tagOI_EVENT
{
	OI_EVENT_AXIS_INITIALIZED,
	OI_EVENT_MOVE_STARTED

} OI_EVENT_ID;

typedef struct tagEVENT_INFO
{
	UINT		uStructSize;
	UINT		uAffectedAxes;
	int			iReturnCode; 
	double		dVals[10];
} OI_EVENT_INFO;

typedef struct tagMOVE_Z_SYNC_STATUS
{
	int		iIsListEnabled;
	int		iListCount;
	int		iIsListValid;
	int		iCurrentPoint;
	double	dTargetZ;
	double	dActualZ;
} MOVE_Z_SYNC_STATUS;

#endif //_OI_CONST_H